<?php

/**
 * Content section
 *
 * @package Krste
 */
use  LottaFramework\Customizer\Controls\Border ;
use  LottaFramework\Customizer\Controls\BoxShadow ;
use  LottaFramework\Customizer\Controls\ColorPicker ;
use  LottaFramework\Customizer\Controls\Placeholder ;
use  LottaFramework\Customizer\Controls\Section ;
use  LottaFramework\Customizer\Controls\Separator ;
use  LottaFramework\Customizer\Controls\Spacing ;
use  LottaFramework\Customizer\Controls\Typography ;
use  LottaFramework\Customizer\Section as CustomizerSection ;

if ( !defined( 'ABSPATH' ) ) {
    exit;
    // Exit if accessed directly.
}

if ( !class_exists( 'Krste_Content_Section' ) ) {
    class Krste_Content_Section extends CustomizerSection
    {
        use  Krste_Button_Controls ;
        /**
         * {@inheritDoc}
         */
        public function getControls()
        {
            return [
                ( new Section( 'krste_content_colors' ) )->setLabel( __( 'Colors', 'krste' ) )->setControls( $this->getColorsControls() ),
                ( new Section( 'krste_content_typography' ) )->setLabel( __( 'Typography', 'krste' ) )->setControls( $this->getTypographyControls() ),
                ( new Section( 'krste_content_buttons' ) )->setLabel( __( 'Buttons', 'krste' ) )->setControls( $this->getButtonStyleControls( 'krste_content_buttons_' ) ),
                ( new Section( 'krste_content_images' ) )->setLabel( __( 'Images', 'krste' ) )->setControls( $this->getImagesControls() ),
                ( new Section( 'krste_content_comments' ) )->setLabel( __( 'Comments Area', 'krste' ) )->setControls( $this->getCommentsControls() )
            ];
        }
        
        /**
         * @return array
         */
        protected function getTypographyControls()
        {
            $fonts = [
                'base_typography'     => [
                'label'   => __( 'Base Typography', 'krste' ),
                'default' => [
                'family'     => 'inherit',
                'fontSize'   => '1rem',
                'variant'    => '400',
                'lineHeight' => '1.75',
            ],
            ],
                'drop_cap_typography' => [
                'label'   => __( 'Drop Cap', 'krste' ),
                'default' => [
                'family'        => 'serif',
                'fontSize'      => '5rem',
                'variant'       => '700',
                'lineHeight'    => '1',
                'textTransform' => 'uppercase',
            ],
            ],
                'h1_typography'       => [
                'label'   => __( 'Heading 1 (H1)', 'krste' ),
                'default' => [
                'family'     => 'serif',
                'fontSize'   => '2.5rem',
                'variant'    => '700',
                'lineHeight' => '1.11',
            ],
            ],
                'h2_typography'       => [
                'label'   => __( 'Heading 2 (H2)', 'krste' ),
                'default' => [
                'family'     => 'serif',
                'fontSize'   => '2rem',
                'variant'    => '700',
                'lineHeight' => '1.33',
            ],
            ],
                'h3_typography'       => [
                'label'   => __( 'Heading 3 (H3)', 'krste' ),
                'default' => [
                'family'     => 'serif',
                'fontSize'   => '1.75rem',
                'variant'    => '700',
                'lineHeight' => '1.6',
            ],
            ],
                'h4_typography'       => [
                'label'   => __( 'Heading 4 (H4)', 'krste' ),
                'default' => [
                'family'     => 'serif',
                'fontSize'   => '1.5rem',
                'variant'    => '600',
                'lineHeight' => '1.5',
            ],
            ],
                'h5_typography'       => [
                'label'   => __( 'Heading 5 (H5)', 'krste' ),
                'default' => [
                'family'     => 'serif',
                'fontSize'   => '1.125rem',
                'variant'    => '600',
                'lineHeight' => '1.5',
            ],
            ],
                'h6_typography'       => [
                'label'   => __( 'Heading 6 (H6)', 'krste' ),
                'default' => [
                'family'     => 'serif',
                'fontSize'   => '1rem',
                'variant'    => '500',
                'lineHeight' => '1.125',
            ],
            ],
            ];
            $controls = [];
            foreach ( $fonts as $item => $font ) {
                $controls[] = ( new Typography( 'krste_content_' . $item ) )->setLabel( $font['label'] )->setDefaultValue( $font['default'] );
            }
            return $controls;
        }
        
        /**
         * @return array
         */
        protected function getColorsControls()
        {
            $colors = [
                'base_color'     => [
                'label'  => __( 'Base Color', 'krste' ),
                'colors' => [
                'initial' => 'var(--krste-accent-color)',
            ],
            ],
                'drop_cap_color' => [
                'label'  => __( 'Drop Cap Color', 'krste' ),
                'colors' => [
                'initial' => 'var(--krste-accent-active)',
            ],
            ],
                'link_color'     => [
                'label'  => __( 'Links Color', 'krste' ),
                'colors' => [
                'initial' => 'var(--krste-primary-color)',
                'hover'   => 'var(--krste-primary-active)',
            ],
            ],
                'headings_color' => [
                'label'  => __( 'All Headings Color (H1 - H6)', 'krste' ),
                'colors' => [
                'initial' => 'var(--krste-accent-active)',
            ],
            ],
                'h1_color'       => [
                'label'  => __( 'Headings 1 (H1)', 'krste' ),
                'colors' => [
                'initial' => 'var(--krste-headings-color)',
            ],
            ],
                'h2_color'       => [
                'label'  => __( 'Headings 2 (H2)', 'krste' ),
                'colors' => [
                'initial' => 'var(--krste-headings-color)',
            ],
            ],
                'h3_color'       => [
                'label'  => __( 'Headings 3 (H3)', 'krste' ),
                'colors' => [
                'initial' => 'var(--krste-headings-color)',
            ],
            ],
                'h4_color'       => [
                'label'  => __( 'Headings 4 (H4)', 'krste' ),
                'colors' => [
                'initial' => 'var(--krste-headings-color)',
            ],
            ],
                'h5_color'       => [
                'label'  => __( 'Headings 5 (H5)', 'krste' ),
                'colors' => [
                'initial' => 'var(--krste-headings-color)',
            ],
            ],
                'h6_color'       => [
                'label'  => __( 'Headings 6 (H6)', 'krste' ),
                'colors' => [
                'initial' => 'var(--krste-headings-color)',
            ],
            ],
            ];
            $controls = [];
            foreach ( $colors as $item => $color ) {
                $picker = new ColorPicker( 'krste_content_' . $item );
                $picker->setLabel( $color['label'] );
                foreach ( $color['colors'] as $id => $value ) {
                    $picker->addColor( $id, ucfirst( $id ), $value );
                }
                $controls[] = $picker;
            }
            return $controls;
        }
        
        /**
         * @return array
         */
        protected function getImagesControls()
        {
            $controls = [
                ( new Border( 'krste_content_images_border' ) )->setLabel( __( 'Border', 'krste' ) )->setDefaultBorder( 4, 'none', 'var(--krste-accent-color)' ),
                new Separator(),
                ( new Spacing( 'krste_content_images_radius' ) )->setLabel( __( 'Border Radius', 'krste' ) )->enableResponsive()->setDefaultValue( [
                'top'    => '2px',
                'right'  => '2px',
                'bottom' => '2px',
                'left'   => '2px',
                'linked' => true,
            ] ),
                new Separator()
            ];
            $controls[] = krste_upsell_info_control( __( 'More image options in %1$sPro Version%2$s', 'krste' ) );
            return $controls;
        }
        
        /**
         * @return array
         */
        protected function getCommentsControls()
        {
            $controls = [ ( new Placeholder( 'krste_content_comments_typography' ) )->setDefaultValue( [
                'family'     => 'inherit',
                'fontSize'   => '0.85rem',
                'variant'    => '400',
                'lineHeight' => '1.5em',
            ] ), ( new Placeholder( 'krste_content_comments_text_color' ) )->setDefaultValue( [
                'initial' => 'var(--krste-accent-active)',
                'hover'   => 'var(--krste-primary-color)',
            ] ), ( new Placeholder( 'krste_content_comments_form_color' ) )->setDefaultValue( [
                'background' => 'var(--krste-base-100)',
                'border'     => 'var(--krste-base-300)',
                'active'     => 'var(--krste-primary-color)',
            ] ) ];
            $controls = array_merge( $controls, [
                ( new Border( 'krste_content_comments_border_top' ) )->setLabel( __( 'Top Border', 'krste' ) )->enableResponsive()->displayBlock()->setDefaultBorder( 1, 'none', 'var(--krste-base-200)' ),
                new Separator(),
                ( new Border( 'krste_content_comments_border_bottom' ) )->setLabel( __( 'Bottom Border', 'krste' ) )->enableResponsive()->displayBlock()->setDefaultBorder( 1, 'none', 'var(--krste-base-200)' ),
                new Separator(),
                ( new Spacing( 'krste_content_comments_padding' ) )->setLabel( __( 'Padding', 'krste' ) )->enableResponsive()->setDisabled( [ 'left', 'right' ] )->setSpacing( [
                'linked' => true,
            ] ),
                ( new Spacing( 'krste_content_comments_margin' ) )->setLabel( __( 'Margin', 'krste' ) )->enableResponsive()->setDisabled( [ 'left', 'right' ] )->setSpacing( [
                'linked' => true,
            ] )
            ] );
            if ( krs_fs()->is_not_paying() ) {
                $controls[] = krste_upsell_info_control( __( 'More options in %1$sPro Version%2$s', 'krste' ) );
            }
            return $controls;
        }
    
    }
}