<?php

/**
 * Footer customizer section
 *
 * @package Krste
 */
use  LottaFramework\Customizer\Controls\Background ;
use  LottaFramework\Customizer\Controls\Border ;
use  LottaFramework\Customizer\Controls\BoxShadow ;
use  LottaFramework\Customizer\Controls\CallToAction ;
use  LottaFramework\Customizer\Controls\Placeholder ;
use  LottaFramework\Customizer\Controls\Radio ;
use  LottaFramework\Customizer\Controls\Section ;
use  LottaFramework\Customizer\Controls\Separator ;
use  LottaFramework\Customizer\Controls\Slider ;
use  LottaFramework\Customizer\Controls\Spacing ;
use  LottaFramework\Customizer\Section as CustomizerSection ;

if ( !defined( 'ABSPATH' ) ) {
    exit;
    // Exit if accessed directly.
}

if ( !class_exists( 'Krste_Footer_Section' ) ) {
    class Krste_Footer_Section extends CustomizerSection
    {
        /**
         * {@inheritDoc}
         */
        public function getControls()
        {
            return [
                ( new Section( 'krste_footer_style' ) )->setLabel( __( 'Container', 'krste' ) )->selectiveRefresh( ...krste_refresh_dynamic_css() )->setControls( $this->getFooterContainerControls() ),
                ( new Section( 'krste_footer_logo' ) )->enableSwitch()->setLabel( __( 'Logo', 'krste' ) )->setControls( $this->getLogoControls() ),
                ( new Section( 'krste_footer_menu' ) )->enableSwitch()->setLabel( __( 'Menu', 'krste' ) )->setControls( $this->getMenuControls() ),
                ( new Section( 'krste_footer_copyright' ) )->setLabel( __( 'Copyright', 'krste' ) )->setControls( $this->getCopyrightControls() )
            ];
        }
        
        protected function getFooterContainerControls()
        {
            $controls = [ ( new Radio( 'krste_footer_content_alignment' ) )->setLabel( __( 'Content Alignment', 'krste' ) )->buttonsGroupView()->selectiveRefresh( ...krste_refresh_dynamic_css() )->setDefaultValue( 'center' )->setChoices( [
                'flex-start' => __( 'Left', 'krste' ),
                'center'     => __( 'Center', 'krste' ),
                'flex-end'   => __( 'Right', 'krste' ),
            ] ) ];
            $controls = array_merge( $controls, [
                ( new Placeholder( 'krste_footer_items_spacing' ) )->setDefaultValue( '24px' ),
                ( new Placeholder( 'krste_footer_border_top' ) )->setDefaultBorder( 1, 'none', 'var(--krste-base-200)' ),
                ( new Placeholder( 'krste_footer_border_bottom' ) )->setDefaultBorder( 1, 'none', 'var(--krste-base-200)' ),
                ( new Placeholder( 'krste_footer_shadow' ) )->setDefaultShadow(
                'rgba(44, 62, 80, 0.05)',
                '0px',
                '-4px',
                '4px',
                '0px',
                false
            )
            ] );
            $controls = array_merge( $controls, [
                new Separator(),
                ( new Background( 'krste_footer_background' ) )->setLabel( __( 'Background', 'krste' ) )->enableResponsive()->selectiveRefresh( ...krste_refresh_dynamic_css() )->setDefaultValue( [
                'type'  => 'color',
                'color' => 'var(--krste-accent-active)',
            ] ),
                new Separator(),
                ( new Spacing( 'krste_footer_margin' ) )->setLabel( __( 'Margin', 'krste' ) )->setDisabled( [ 'left', 'right' ] )->setSpacing( [
                'top'    => '48px',
                'linked' => true,
            ] ),
                ( new Spacing( 'krste_footer_padding' ) )->setLabel( __( 'Padding', 'krste' ) )->setDisabled( [ 'left', 'right' ] )->setSpacing( [
                'top'    => '48px',
                'bottom' => '48px',
                'linked' => true,
            ] )
            ] );
            if ( krs_fs()->is_not_paying() ) {
                $controls[] = krste_upsell_info_control( __( 'More footer options in %1$sPro Version%2$s', 'krste' ) );
            }
            return $controls;
        }
        
        /**
         * Get logo controls
         *
         * @return array
         */
        protected function getLogoControls()
        {
            $logo = new Krste_Logo_Element( 'krste_footer_logo', [
                'position'          => 'top',
                'content-alignment' => 'center',
                'title-initial'     => 'var(--krste-base-color)',
                'title-hover'       => 'var(--krste-base-color)',
                'tagline-initial'   => 'var(--krste-base-300)',
            ] );
            return $logo->getControls();
        }
        
        /**
         * Get menu controls
         *
         * @return array
         */
        protected function getMenuControls()
        {
            $menu = new Krste_Menu_Element( 'krste_footer_menu', [
                'depth'                  => 1,
                'top-level-text-initial' => 'var(--krste-base-300)',
                'top-level-padding'      => [
                'top'    => '4px',
                'bottom' => '4px',
                'left'   => '4px',
                'right'  => '4px',
                'linked' => true,
            ],
                'top-level-typography'   => [
                'family'        => 'inherit',
                'fontSize'      => '0.85rem',
                'variant'       => '400',
                'lineHeight'    => '1',
                'textTransform' => 'capitalize',
            ],
            ] );
            return array_merge( [ ( new CallToAction() )->setLabel( __( 'Edit Menu Locations', 'krste' ) )->displayAsButton()->expandCustomize( 'menu_locations' ), new Separator() ], $menu->getControls() );
        }
        
        /**
         * Get copyright controls
         *
         * @return array
         */
        protected function getCopyrightControls()
        {
            $copyright = new Krste_Copyright_Element( 'krste_footer_copyright' );
            return $copyright->getControls();
        }
    
    }
}