<?php
/**
 * Copyright element
 *
 * @package Krste
 */

use LottaFramework\Customizer\Controls\ColorPicker;
use LottaFramework\Customizer\Controls\Editor;
use LottaFramework\Customizer\Controls\Tabs;
use LottaFramework\Customizer\Controls\Typography;
use LottaFramework\Facades\Css;
use LottaFramework\Facades\CZ;
use LottaFramework\Utils;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! class_exists( 'Krste_Copyright_Element' ) ) {

	class Krste_Copyright_Element extends Krste_Reusable_Element {

		/**
		 * {@inheritDoc}
		 */
		public function getControls(): array {
			return [
				( new Tabs() )
					->setActiveTab( 'content' )
					->addTab( 'content', __( 'Content', 'krste' ), $this->getContentControls() )
					->addTab( 'style', __( 'Style', 'krste' ), [
						( new Typography( $this->getSlug( 'typography' ) ) )
							->setLabel( __( 'Typography', 'krste' ) )
							->setDefaultValue( [
								'family'     => 'inherit',
								'fontSize'   => '0.85rem',
								'variant'    => '400',
								'lineHeight' => '1.5em'
							] )
						,
						( new ColorPicker( $this->getSlug( 'color' ) ) )
							->setLabel( __( 'Color', 'krste' ) )
							->enableAlpha()
							->addColor( 'text', __( 'Text Initial', 'krste' ), 'var(--krste-base-300)' )
							->addColor( 'initial', __( 'Initial', 'krste' ), 'var(--krste-primary-color)' )
							->addColor( 'hover', __( 'Hover', 'krste' ), 'var(--krste-primary-active)' )
						,
					] )
				,
			];
		}

		/**
		 * @return array
		 */
		protected function getContentControls() {
			return [
				( new Editor( $this->getSlug( 'text' ) ) )
					->setLabel( __( 'Copyright Text', 'krste' ) )
					->setDescription( __( 'You can insert some arbitrary HTML code tags: {current_year}, {site_title}, {about_theme} and {about_author}', 'krste' ) )
					->setToolbar1( 'bold,italic,link,undo,redo' )
					->setDefaultValue( 'Copyright &copy; {current_year} {site_title}' )
				,
			];
		}

		/**
		 * {@inheritDoc}
		 */
		public function css( array $css = [] ): array {
			$css[".$this->id"] = array_merge(
				Css::typography( CZ::get( $this->getSlug( 'typography' ) ) ),
				Css::colors( CZ::get( $this->getSlug( 'color' ) ), [
					'text'    => 'color',
					'initial' => '--krste-link-initial-color',
					'hover'   => '--krste-link-hover-color',
				] )
			);

			return $css;
		}

		/**
		 * {@inheritDoc}
		 */
		public function render( array $attrs = [] ) {

			$attrs['class'] = Utils::clsx( [
				'krste-copyright',
				'krste-raw-html',
				$this->id
			], $attrs['class'] ?? [] );

			foreach ( $attrs as $attr => $value ) {
				$this->add_render_attribute( 'copyright', $attr, $value );
			}

			$theme       = wp_get_theme();
			$theme_info  = sprintf( '<a href="%s" target="_blank">%s</a>', esc_url( $theme->get( 'ThemeURI' ) ), $theme->get( 'Name' ) . ' ' . __( 'Theme', 'krste' ) );
			$author_info = sprintf( '<a href="%s" target="_blank">%s</a>', esc_url( $theme->get( 'AuthorURI' ) ), $theme->get( 'Author' ) );

			$text = CZ::get( $this->getSlug( 'text' ) );
			$text .= ' &nbsp; - &nbsp; {about_theme} Designed & Developed By {about_author}';

			$text = str_replace( '{current_year}', date( 'Y' ), $text );
			$text = str_replace( '{site_title}', get_bloginfo( 'name' ), $text );
			$text = str_replace( '{about_theme}', $theme_info, $text );
			$text = str_replace( '{about_author}', $author_info, $text );

			?>
			<div <?php $this->print_attribute_string( 'copyright' ); ?>>
				<?php echo wp_kses_post( $text ); ?>
			</div>
			<?php
		}
	}

}