<?php
/**
 * Logo element
 *
 * @package Krste
 */

use LottaFramework\Customizer\Controls\CallToAction;
use LottaFramework\Customizer\Controls\ColorPicker;
use LottaFramework\Customizer\Controls\ImageUploader;
use LottaFramework\Customizer\Controls\Radio;
use LottaFramework\Customizer\Controls\Separator;
use LottaFramework\Customizer\Controls\Slider;
use LottaFramework\Customizer\Controls\Tabs;
use LottaFramework\Customizer\Controls\Toggle;
use LottaFramework\Customizer\Controls\Typography;
use LottaFramework\Facades\Css;
use LottaFramework\Facades\CZ;
use LottaFramework\Utils;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! class_exists( 'Krste_Logo_Element' ) ) {

	class Krste_Logo_Element extends Krste_Reusable_Element {

		/**
		 * {@inheritDoc}
		 */
		public function getControls(): array {
			return [
				( new Tabs() )
					->setActiveTab( 'content' )
					->addTab( 'content', __( 'Content', 'krste' ), [
						( new ImageUploader( $this->getSlug( 'logo' ) ) )
							->setLabel( __( 'Logo', 'krste' ) )
							->setDefaultValue( $this->getDefaultSetting( 'logo', '' ) )
						,
						( new Separator() )->dashedStyle(),
						( new Radio( $this->getSlug( 'position' ) ) )
							->setLabel( __( 'Logo Position', 'krste' ) )
							->buttonsGroupView()
							->setDefaultValue( $this->getDefaultSetting( 'position', 'left' ) )
							->setChoices( [
								'left'  => __( 'Left', 'krste' ),
								'right' => __( 'Right', 'krste' ),
								'top'   => __( 'Top', 'krste' ),
							] )
						,
						( new Slider( $this->getSlug( 'height' ) ) )
							->setLabel( __( 'Logo Height', 'krste' ) )
							->setMin( 0 )
							->setMax( 300 )
							->setDefaultUnit( 'px' )
							->setDefaultValue( $this->getDefaultSetting( 'height', '40px' ) )
						,
						( new Slider( $this->getSlug( 'spacing' ) ) )
							->setLabel( __( 'Logo Spacing', 'krste' ) )
							->setMin( 0 )
							->setMax( 300 )
							->setDefaultUnit( 'px' )
							->setDefaultValue( $this->getDefaultSetting( 'spacing', '12px' ) )
						,
						( new Separator() )->dashedStyle(),
						( new Toggle( $this->getSlug( 'enable_site_title' ) ) )
							->setLabel( __( 'Site Title', 'krste' ) )
							->setDefaultValue( $this->getDefaultSetting( 'enable-site-title', 'yes' ) )
						,
						( new Toggle( $this->getSlug( 'enable_site_tagline' ) ) )
							->setLabel( __( 'Site Tagline', 'krste' ) )
							->setDefaultValue( $this->getDefaultSetting( 'enable-site-tagline', 'no' ) )
						,
						( new CallToAction() )
							->setLabel( __( 'Click here to change the site title and tagline.', 'krste' ) )
							->expandCustomize( 'title_tagline' )
						,
						( new Separator() )->dashedStyle(),
						( new Radio( $this->getSlug( 'content_alignment' ) ) )
							->setLabel( __( 'Content Alignment', 'krste' ) )
							->buttonsGroupView()
							->setDefaultValue( $this->getDefaultSetting( 'content-alignment', 'left' ) )
							->setChoices( [
								'left'   => __( 'Left', 'krste' ),
								'center' => __( 'Center', 'krste' ),
								'right'  => __( 'Right', 'krste' ),
							] )
						,
					] )
					->addTab( 'style', __( 'Style', 'krste' ), [
						( new Typography( $this->getSlug( 'site_title_typography' ) ) )
							->setLabel( __( 'Site Title Typography', 'krste' ) )
							->setDefaultValue( $this->getDefaultSetting( 'site-title-typography', [
								'family'        => 'italianno',
								'fontSize'      => '48px',
								'variant'       => '400',
								'lineHeight'    => '1',
								'textTransform' => 'capitalize',
							] ) )
						,
						( new ColorPicker( $this->getSlug( 'site_title_color' ) ) )
							->setLabel( __( 'Site Title Color', 'krste' ) )
							->enableAlpha()
							->addColor( 'initial', __( 'Initial', 'krste' ),
								$this->getDefaultSetting( 'title-initial', 'var(--krste-accent-active)' ) )
							->addColor( 'hover', __( 'Hover', 'krste' ),
								$this->getDefaultSetting( 'title-hover', 'var(--krste-primary-color)' ) )
						,
						( new Separator() )->dashedStyle(),
						( new Typography( $this->getSlug( 'site_tagline_typography' ) ) )
							->setLabel( __( 'Site Tagline Typography', 'krste' ) )
							->setDefaultValue( $this->getDefaultSetting( 'site-tagline-typography', [
								'family'     => 'inherit',
								'fontSize'   => '14px',
								'variant'    => '500',
								'lineHeight' => '1.5',
							] ) )
						,
						( new ColorPicker( $this->getSlug( 'site_tagline_color' ) ) )
							->setLabel( __( 'Site Tagline Color', 'krste' ) )
							->enableAlpha()
							->addColor( 'initial', __( 'Initial', 'krste' ),
								$this->getDefaultSetting( 'tagline-initial', 'var(--krste-accent-color)' ) )
						,
					] )
			];
		}

		/**
		 * {@inheritDoc}
		 */
		public function css( array $css = [] ): array {

			$css[".{$this->getSlug()}"] = [
				'--logo-max-height' => CZ::get( $this->getSlug( 'height' ) ),
				'--logo-spacing'    => CZ::get( $this->getSlug( 'spacing' ) ),
				'text-align'        => CZ::get( $this->getSlug( 'content_alignment' ) ),
			];

			if ( CZ::checked( $this->getSlug( 'enable_site_title' ) ) ) {
				$css[".{$this->getSlug()} .site-title"] = array_merge(
					Css::typography( CZ::get( $this->getSlug( 'site_title_typography' ) ) ),
					Css::colors( CZ::get( $this->getSlug( 'site_title_color' ) ), [
						'initial' => '--text-color',
						'hover'   => '--hover-color',
					] )
				);
			}

			if ( CZ::checked( $this->getSlug( 'enable_site_tagline' ) ) ) {
				$css[".{$this->getSlug()} .site-tagline"] = array_merge(
					Css::typography( CZ::get( $this->getSlug( 'site_tagline_typography' ) ) ),
					Css::colors( CZ::get( $this->getSlug( 'site_tagline_color' ) ), [
						'initial' => 'color',
					] )
				);
			}

			return $css;
		}

		/**
		 * {@inheritDoc}
		 */
		public function render( array $attrs = [] ) {

			$wrapper_attrs = $attrs['attrs'] ?? [];

			$wrapper_attrs['class'] = Utils::clsx(
				$wrapper_attrs['class'] ?? [],
				[ 'krste-site-branding', $this->getSlug() ]
			);

			$wrapper_attrs['data-logo'] = CZ::get( $this->getSlug( 'position' ) );

			if ( is_customize_preview() && isset( $attrs['location'] ) ) {
				$wrapper_attrs['data-shortcut']          = 'arrow';
				$wrapper_attrs['data-shortcut-location'] = $attrs['location'];
			}

			$logo_attr = [];

			$logo          = CZ::get( $this->getSlug( 'logo' ) );
			$attachment_id = $logo['attachment_id'] ?? 0;
			if ( $attachment_id > 0 ) {
				$alt_attribute    = get_post_meta( $attachment_id, '_wp_attachment_image_alt', true );
				$alt_attribute    = ! empty( $alt_attribute ) ? $alt_attribute : get_bloginfo( 'name' );
				$logo_attr['src'] = esc_url( $logo['url'] ?? '' );
				$logo_attr['alt'] = esc_attr( $alt_attribute );
			}

			$title = CZ::checked( $this->getSlug( 'enable_site_title' ) )
				? get_bloginfo( 'name' )
				: '';

			$tagline = CZ::checked( $this->getSlug( 'enable_site_tagline' ) )
				? get_bloginfo( 'description' )
				: '';

			?>
            <div <?php Utils::print_attribute_string( $wrapper_attrs ); ?>>
				<?php if ( $attachment_id > 0 ): ?>
                    <a class="site-logo" href="<?php echo esc_url( home_url() ) ?>">
                        <img <?php Utils::print_attribute_string( $logo_attr ); ?> />
                    </a>
				<?php endif; ?>
                <div class="site-identity">
					<?php if ( $title !== '' ): ?>
                        <span class="site-title">
                        <a href="<?php echo esc_url( home_url() ) ?>"><?php echo esc_html( $title ) ?></a>
                    </span>
					<?php endif; ?>
					<?php if ( $tagline !== '' ): ?>
                        <span class="site-tagline">
                        <?php echo esc_html( $tagline ) ?>
                    </span>
					<?php endif; ?>
                </div>
            </div>
			<?php
		}
	}

}