<?php

/**
 * Menu element
 *
 * @package Krste
 */
use  LottaFramework\Customizer\Controls\Border ;
use  LottaFramework\Customizer\Controls\BoxShadow ;
use  LottaFramework\Customizer\Controls\ColorPicker ;
use  LottaFramework\Customizer\Controls\Condition ;
use  LottaFramework\Customizer\Controls\ImageRadio ;
use  LottaFramework\Customizer\Controls\Placeholder ;
use  LottaFramework\Customizer\Controls\Radio ;
use  LottaFramework\Customizer\Controls\Section ;
use  LottaFramework\Customizer\Controls\Separator ;
use  LottaFramework\Customizer\Controls\Slider ;
use  LottaFramework\Customizer\Controls\Spacing ;
use  LottaFramework\Customizer\Controls\Tabs ;
use  LottaFramework\Customizer\Controls\Toggle ;
use  LottaFramework\Customizer\Controls\Typography ;
use  LottaFramework\Facades\Css ;
use  LottaFramework\Facades\CZ ;
use  LottaFramework\Utils ;

if ( !defined( 'ABSPATH' ) ) {
    exit;
    // Exit if accessed directly.
}

if ( !class_exists( 'Krste_Menu_Element' ) ) {
    class Krste_Menu_Element extends Krste_Reusable_Element
    {
        /**
         * @return array
         */
        protected function getTopLevelGeneralControls()
        {
            return [
                ( new Slider( $this->getSlug( 'top_level_height' ) ) )->setLabel( __( 'Items Height', 'krste' ) )->setDefaultValue( $this->getDefaultSetting( 'top-level-height', '50%' ) )->setDefaultUnit( '%' )->setMin( 5 )->setMax( 100 ),
                new Separator(),
                ( new Spacing( $this->getSlug( 'top_level_margin' ) ) )->setLabel( __( 'Items Margin', 'krste' ) )->setDisabled( [ 'top', 'bottom' ] )->setDefaultValue( $this->getDefaultSetting( 'top-level-margin', [
                'top'    => '0',
                'bottom' => '0',
                'left'   => '',
                'right'  => '',
                'linked' => true,
            ] ) ),
                ( new Spacing( $this->getSlug( 'top_level_padding' ) ) )->setLabel( __( 'Items Padding', 'krste' ) )->setDefaultValue( $this->getDefaultSetting( 'top-level-padding', [
                'top'    => '4px',
                'bottom' => '4px',
                'left'   => '8px',
                'right'  => '8px',
                'linked' => false,
            ] ) ),
                new Separator(),
                ( new Spacing( $this->getSlug( 'top_level_radius' ) ) )->setLabel( __( 'Items Border Radius', 'krste' ) )->setDefaultValue( $this->getDefaultSetting( 'top-level-radius', [
                'top'    => '0',
                'bottom' => '0',
                'left'   => '0',
                'right'  => '0',
                'linked' => true,
            ] ) )
            ];
        }
        
        /**
         * @return array
         */
        protected function getTopLevelStyleControls()
        {
            $controls = [ ( new Typography( $this->getSlug( 'top_level_typography' ) ) )->setLabel( __( 'Typography', 'krste' ) )->setDefaultValue( $this->getDefaultSetting( 'top-level-typography', [
                'family'        => 'inherit',
                'fontSize'      => '0.85rem',
                'variant'       => '600',
                'lineHeight'    => '1',
                'textTransform' => 'capitalize',
            ] ) ) ];
            $controls = array_merge( $controls, [ ( new Placeholder( $this->getSlug( 'top_level_text_color' ) ) )->setDefaultValue( [
                'initial' => $this->getDefaultSetting( 'top-level-text-initial', 'var(--krste-accent-color)' ),
                'hover'   => $this->getDefaultSetting( 'top-level-text-hover', 'var(--krste-primary-color)' ),
                'active'  => $this->getDefaultSetting( 'top-level-text-active', 'var(--krste-primary-color)' ),
            ] ), ( new Placeholder( $this->getSlug( 'top_level_background_color' ) ) )->setDefaultValue( [
                'initial' => $this->getDefaultSetting( 'top-level-background-initial', 'var(--krste-transparent)' ),
                'hover'   => $this->getDefaultSetting( 'top-level-background-hover', 'var(--krste-transparent)' ),
                'active'  => $this->getDefaultSetting( 'top-level-background-active', 'var(--krste-transparent)' ),
            ] ), krste_upsell_info_control( __( 'Fully customize top level menu items in our %1$sPro Version%2$s', 'krste' ) )->hideBackground() ] );
            return $controls;
        }
        
        /**
         * @return array
         */
        protected function getDropdownGeneralControls()
        {
            return [
                ( new Slider( $this->getSlug( 'dropdown_width' ) ) )->setLabel( __( 'Min Width', 'krste' ) )->setDefaultValue( $this->getDefaultSetting( 'dropdown-width', '200px' ) )->setMin( 100 )->setMax( 300 ),
                ( new Radio( $this->getSlug( 'dropdown_direction' ) ) )->setLabel( __( 'Direction', 'krste' ) )->setDefaultValue( $this->getDefaultSetting( 'dropdown-direction', 'right' ) )->setChoices( [
                'left'  => __( 'Left', 'krste' ),
                'right' => __( 'Right', 'krste' ),
            ] ),
                new Separator(),
                ( new Spacing( $this->getSlug( 'dropdown_item_padding' ) ) )->setLabel( __( 'Items Padding', 'krste' ) )->setDefaultValue( $this->getDefaultSetting( 'dropdown-item-padding', [
                'top'    => '14px',
                'bottom' => '14px',
                'left'   => '14px',
                'right'  => '14px',
                'linked' => true,
            ] ) ),
                ( new Spacing( $this->getSlug( 'dropdown_radius' ) ) )->setLabel( __( 'Dropdown Border Radius', 'krste' ) )->setDefaultValue( $this->getDefaultSetting( 'dropdown-radius', [
                'top'    => '2px',
                'bottom' => '2px',
                'left'   => '2px',
                'right'  => '2px',
                'linked' => true,
            ] ) )
            ];
        }
        
        /**
         * @return array
         */
        protected function getDropdownStyleControls()
        {
            $controls = [ ( new Typography( $this->getSlug( 'dropdown_typography' ) ) )->setLabel( __( 'Typography', 'krste' ) )->setDefaultValue( $this->getDefaultSetting( 'dropdown-typography', [
                'family'     => 'inherit',
                'fontSize'   => '0.75rem',
                'variant'    => '500',
                'lineHeight' => '1',
            ] ) ) ];
            $controls = array_merge( $controls, [
                ( new Placeholder( $this->getSlug( 'dropdown_text_color' ) ) )->setDefaultValue( [
                'initial' => 'var(--krste-accent-color)',
                'hover'   => 'var(--krste-primary-color)',
                'active'  => 'var(--krste-primary-color)',
            ] ),
                ( new Placeholder( $this->getSlug( 'dropdown_background_color' ) ) )->setDefaultValue( [
                'initial' => 'var(--krste-base-color)',
                'active'  => 'var(--krste-base-color)',
            ] ),
                ( new Placeholder( $this->getSlug( 'dropdown_divider' ) ) )->setDefaultBorder( ...$this->getDefaultSetting( 'dropdown-divider', [ 1, 'dashed', 'var(--krste-base-200)' ] ) ),
                ( new Placeholder( $this->getSlug( 'dropdown_shadow' ) ) )->setDefaultShadow( ...$this->getDefaultSetting( 'dropdown-shadow', [
                'rgba(44, 62, 80, 0.2)',
                '0px',
                '0px',
                '15px',
                '0px',
                true
            ] ) ),
                krste_upsell_info_control( __( 'Fully customize menu dropdown in our %1$sPro Version%2$s', 'krste' ) )->hideBackground()
            ] );
            return $controls;
        }
        
        /**
         * Get all controls
         *
         * @return array
         */
        public function getControls() : array
        {
            $controls = [ ( new Slider( $this->getSlug( 'depth' ) ) )->setLabel( __( 'Menu Depth', 'krste' ) )->setDescription( __( '"0" meas no limit.', 'krste' ) )->displayInline()->setMin( 0 )->setMax( 10 )->setDefaultUnit( false )->setDefaultValue( $this->getDefaultSetting( 'depth', 0 ) ) ];
            $controls = array_merge( $controls, [ ( new Placeholder( $this->getSlug( 'arrow' ) ) )->setDefaultValue( $this->getDefaultSetting( 'arrow', 'yes' ) ), ( new Placeholder( $this->getSlug( 'arrow-icon' ) ) )->setDefaultValue( 'toggle-1' ), ( new Placeholder( $this->getSlug( 'spacing' ) ) )->setSpacing( [
                'left'  => '48px',
                'right' => '48px',
            ] ) ] );
            $controls = array_merge( $controls, [
                new Separator(),
                ( new Radio( $this->getSlug( 'alignment' ) ) )->setLabel( __( 'Menu Alignment', 'krste' ) )->buttonsGroupView()->selectiveRefresh( ...krste_refresh_dynamic_css() )->setDefaultValue( 'center' )->setChoices( [
                'flex-start' => __( 'Left', 'krste' ),
                'center'     => __( 'Center', 'krste' ),
                'flex-end'   => __( 'Right', 'krste' ),
            ] ),
                ( new Section() )->setLabel( __( 'Top Level Options', 'krste' ) )->keepMarginBelow()->setControls( [ ( new Tabs() )->setActiveTab( 'general' )->addTab( 'general', __( 'General', 'krste' ), $this->getTopLevelGeneralControls() )->addTab( 'style', __( 'Style', 'krste' ), $this->getTopLevelStyleControls() ) ] ),
                ( new Condition() )->setCondition( [
                $this->getSlug( 'depth' ) => '!1',
            ] )->setControls( [ ( new Section() )->keepMarginBelow()->setLabel( __( 'Dropdown Options', 'krste' ) )->setControls( [ ( new Tabs() )->setActiveTab( 'general' )->addTab( 'general', __( 'General', 'krste' ), $this->getDropdownGeneralControls() )->addTab( 'style', __( 'Style', 'krste' ), $this->getDropdownStyleControls() ) ] ) ] )
            ] );
            if ( krs_fs()->is_not_paying() ) {
                $controls[] = krste_upsell_info_control( __( 'More menu options in our %1$sPro Version%2$s', 'krste' ) )->hideBackground();
            }
            return $controls;
        }
        
        /**
         * Generate dynamic css for menu
         *
         * @param array $css
         *
         * @return array
         */
        public function css( array $css = array() ) : array
        {
            // top level typography
            $css[".{$this->id} > li"] = Css::typography( CZ::get( $this->getSlug( 'top_level_typography' ) ) );
            // dropdown typography
            $css[".{$this->id} > li ul"] = Css::typography( CZ::get( $this->getSlug( 'dropdown_typography' ) ) );
            $css[".{$this->getSlug( 'wrap' )}"] = array_merge( [
                'justify-content' => CZ::get( $this->getSlug( 'alignment' ) ),
            ], Css::dimensions( CZ::get( $this->getSlug( 'spacing' ) ), 'padding' ) );
            $css['.' . $this->id] = array_merge(
                [
                    '--menu-items-height' => CZ::get( $this->getSlug( 'top_level_height' ) ),
                    '--dropdown-width'    => CZ::get( $this->getSlug( 'dropdown_width' ) ),
                ],
                Css::colors( CZ::get( $this->getSlug( 'top_level_text_color' ) ), [
                    'initial' => '--menu-text-initial-color',
                    'hover'   => '--menu-text-hover-color',
                    'active'  => '--menu-text-active-color',
                ] ),
                Css::colors( CZ::get( $this->getSlug( 'top_level_background_color' ) ), [
                    'initial' => '--menu-background-initial-color',
                    'hover'   => '--menu-background-hover-color',
                    'active'  => '--menu-background-active-color',
                ] ),
                Css::dimensions( CZ::get( $this->getSlug( 'top_level_margin' ) ), '--menu-items-margin' ),
                Css::dimensions( CZ::get( $this->getSlug( 'top_level_padding' ) ), '--menu-items-padding' ),
                Css::dimensions( CZ::get( $this->getSlug( 'top_level_radius' ) ), '--menu-items-radius' ),
                // dropdown css
                Css::colors( CZ::get( $this->getSlug( 'dropdown_text_color' ) ), [
                    'initial' => '--dropdown-text-initial-color',
                    'hover'   => '--dropdown-text-hover-color',
                    'active'  => '--dropdown-text-active-color',
                ] ),
                Css::colors( CZ::get( $this->getSlug( 'dropdown_background_color' ) ), [
                    'initial' => '--dropdown-background-initial-color',
                    'active'  => '--dropdown-background-active-color',
                ] ),
                Css::dimensions( CZ::get( $this->getSlug( 'dropdown_item_padding' ) ), '--dropdown-item-padding' ),
                Css::dimensions( CZ::get( $this->getSlug( 'dropdown_radius' ) ), '--dropdown-radius' ),
                Css::shadow( CZ::get( $this->getSlug( 'dropdown_shadow' ) ), '--dropdown-box-shadow' ),
                Css::border( CZ::get( $this->getSlug( 'dropdown_divider' ) ), '--dropdown-divider' )
            );
            return $css;
        }
        
        /**
         * Do render
         *
         * @param array $attrs
         */
        public function render( array $attrs = array() )
        {
            $menu_attrs = $attrs['menu_attrs'] ?? [];
            $container_attrs = $attrs['container_attrs'] ?? [];
            $container_attrs['class'] = Utils::clsx( 'krste-menu-wrap flex-grow', $this->getSlug( 'wrap' ), $container_attrs['class'] ?? [] );
            foreach ( $menu_attrs as $attr => $value ) {
                $this->add_render_attribute( $this->id, $attr, $value );
            }
            foreach ( $container_attrs as $attr => $value ) {
                $this->add_render_attribute( "{$this->id}-container", $attr, $value );
            }
            $depth = absint( CZ::get( $this->getSlug( 'depth' ) ) );
            $hasArrow = $depth !== 1 && CZ::checked( $this->getSlug( 'arrow' ) );
            echo  '<div ' . $this->render_attribute_string( "{$this->id}-container" ) . '>' ;
            wp_nav_menu( [
                'theme_location' => $this->id,
                'container'      => false,
                'depth'          => $depth,
                'items_wrap'     => '<ul id="%1$s" class="%2$s" ' . $this->render_attribute_string( $this->id ) . '>%3$s</ul>',
                'link_after'     => '<span class="krste-menu-icon">' . krste_image( CZ::get( $this->getSlug( 'arrow-icon' ) ) ) . '</span>',
                'menu_class'     => Utils::clsx(
                'sf-menu clearfix krste-menu',
                $this->id,
                [
                'krste-menu-has-arrow' => $hasArrow,
                'sf-dropdown-left'     => CZ::get( $this->getSlug( 'dropdown_direction' ) ) === 'left',
            ],
                $menu_attrs['class'] ?? []
            ),
                'fallback_cb'    => function ( $args ) {
                // for customize menu style, the default one not work.
                wp_page_menu( array_merge( $args, [
                    'container' => 'ul',
                ] ) );
            },
            ] );
            echo  '</div>' ;
        }
    
    }
}