<?php

/**
 * Mobile Menu element
 *
 * @package Krste
 */
use  LottaFramework\Customizer\Controls\Border ;
use  LottaFramework\Customizer\Controls\ColorPicker ;
use  LottaFramework\Customizer\Controls\Condition ;
use  LottaFramework\Customizer\Controls\ImageRadio ;
use  LottaFramework\Customizer\Controls\Placeholder ;
use  LottaFramework\Customizer\Controls\Radio ;
use  LottaFramework\Customizer\Controls\Separator ;
use  LottaFramework\Customizer\Controls\Slider ;
use  LottaFramework\Customizer\Controls\Toggle ;
use  LottaFramework\Customizer\Controls\Typography ;
use  LottaFramework\Facades\Css ;
use  LottaFramework\Facades\CZ ;
use  LottaFramework\Utils ;

if ( !defined( 'ABSPATH' ) ) {
    exit;
    // Exit if accessed directly.
}

if ( !class_exists( 'Krste_Mobile_Menu_Element' ) ) {
    class Krste_Mobile_Menu_Element extends Krste_Reusable_Element
    {
        /**
         * {@inheritDoc}
         */
        public function getControls() : array
        {
            $controls = [ ( new Slider( $this->getSlug( 'depth' ) ) )->setLabel( __( 'Menu Depth', 'krste' ) )->setDescription( __( '"0" meas no limit.', 'krste' ) )->displayInline()->setMin( 0 )->setMax( 10 )->setDefaultUnit( false )->setDefaultValue( $this->getDefaultSetting( 'depth', 0 ) ) ];
            $controls = array_merge( $controls, [
                ( new Placeholder( $this->getSlug( 'collapsable' ) ) )->setDefaultValue( 'yes' ),
                ( new Placeholder( $this->getSlug( 'toggle-icon' ) ) )->setDefaultValue( 'toggle-1' ),
                ( new Placeholder( $this->getSlug( 'toggle-style' ) ) )->setDefaultValue( 'bordered' ),
                ( new Placeholder( $this->getSlug( 'toggle-border' ) ) )->setDefaultBorder( 1, 'dashed', 'var(--krste-base-200)' ),
                ( new Placeholder( $this->getSlug( 'color' ) ) )->addColor( 'initial', 'var(--krste-accent-color)' )->addColor( 'hover', 'var(--krste-primary-color)' )->addColor( 'active', 'var(--krste-primary-color)' )
            ] );
            $controls = array_merge( $controls, [
                new Separator(),
                ( new Typography( $this->getSlug( 'typography' ) ) )->setLabel( __( 'Typography', 'krste' ) )->setDefaultValue( [
                'family'     => 'inherit',
                'fontSize'   => '1rem',
                'variant'    => '700',
                'lineHeight' => '1.5em',
            ] ),
                new Separator(),
                ( new Border( $this->getSlug( 'divider' ) ) )->setLabel( __( 'Items Divider', 'krste' ) )->setDefaultBorder( 1, 'dashed', 'var(--krste-base-200)' )
            ] );
            if ( krs_fs()->is_not_paying() ) {
                $controls[] = krste_upsell_info_control( __( 'More mobile menu options in our %1$sPro Version%2$s', 'krste' ) );
            }
            return $controls;
        }
        
        /**
         * {@inheritDoc}
         */
        public function css( array $css = array() ) : array
        {
            $color = CZ::get( $this->getSlug( 'color' ) );
            $css[".{$this->id}"] = array_merge( Css::typography( CZ::get( $this->getSlug( 'typography' ) ) ), Css::border( CZ::get( $this->getSlug( 'divider' ) ), '--menu-items-divider' ), [
                '--menu-text-initial-color' => $color['initial'],
                '--menu-text-hover-color'   => $color['hover'],
                '--menu-text-active-color'  => $color['active'],
            ] );
            if ( CZ::get( $this->getSlug( 'toggle-style' ) ) === 'bordered' ) {
                $css[".{$this->id}"] = array_merge( $css[".{$this->id}"], Css::border( CZ::get( $this->getSlug( 'toggle-border' ) ), '--menu-dropdown-toggle-border' ) );
            }
            return $css;
        }
        
        /**
         * {@inheritDoc}
         */
        public function render( array $attrs = array() )
        {
            foreach ( $attrs as $attr => $value ) {
                $this->add_render_attribute( 'menu', $attr, $value );
            }
            $depth = absint( CZ::get( $this->getSlug( 'depth' ) ) );
            $hasArrow = $depth !== 1;
            wp_nav_menu( [
                'theme_location' => $this->id,
                'menu_class'     => Utils::clsx( 'krste-mobile-menu', $this->id, [
                'collapsable'          => CZ::checked( $this->getSlug( 'collapsable' ) ),
                'krste-menu-has-arrow' => $hasArrow,
            ] ),
                'fallback_cb'    => function ( $args ) {
                // for customize menu style, the default one not work.
                wp_page_menu( array_merge( $args, [
                    'container' => 'ul',
                ] ) );
            },
                'items_wrap'     => '<ul id="%1$s" class="%2$s" ' . $this->render_attribute_string( 'menu' ) . '>%3$s</ul>',
                'depth'          => $depth,
                'container'      => false,
                'echo'           => true,
                'link_after'     => '<button type="button" class="krste-dropdown-toggle"><span class="krste-menu-icon">' . krste_image( CZ::get( $this->getSlug( 'toggle-icon' ) ) ) . '</span></button>',
            ] );
        }
    
    }
}