<?php
/**
 * Reusable element abstract
 *
 * @package Krste
 */

use LottaFramework\Customizer\Traits\Renderable;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

if ( ! class_exists( 'Krste_Reusable_Element' ) ) {

	abstract class Krste_Reusable_Element {

		use Renderable;

		/**
		 * @var string
		 */
		protected $id;

		/**
		 * Controls default value
		 *
		 * @var array
		 */
		protected $defaults = [];

		/**
		 * @param $id
		 * @param array $defaults
		 */
		public function __construct( $id, array $defaults = [] ) {
			$this->id       = $id;
			$this->defaults = $defaults;
		}

		/**
		 * Get slug for setting
		 *
		 * @param string $key
		 * @param string $sep
		 *
		 * @return string
		 */
		protected function getSlug( string $key = '', string $sep = '_' ) {
			return $this->id . ( ( $key === '' ) ? '' : $sep . $key );
		}

		/**
		 * Get default setting value
		 *
		 * @param string $key
		 * @param null $default
		 *
		 * @return mixed|null
		 */
		protected function getDefaultSetting( string $key, $default = null ) {
			if ( isset( $this->defaults[ $key ] ) ) {
				return $this->defaults[ $key ];
			}

			return $default;
		}

		/**
		 * Get all controls
		 *
		 * @return array
		 */
		abstract public function getControls(): array;

		/**
		 * Generate dynamic css for element
		 *
		 * @param array $css
		 *
		 * @return array
		 */
		abstract public function css( array $css = [] ): array;

		/**
		 * Do render
		 *
		 * @param array $attrs
		 */
		abstract public function render( array $attrs = [] );
	}

}