<?php

/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Krste
 */
use  LottaFramework\Facades\CZ ;
use  LottaFramework\Utils ;
/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 *
 * @return array
 */
function krste_body_classes( $classes )
{
    $classes[] = 'krste-body overflow-x-hidden';
    // Adds a class of hfeed to non-singular pages.
    if ( !is_singular() ) {
        $classes[] = 'hfeed';
    }
    // Adds a class of no-sidebar when there is no sidebar present.
    $default_sidebar = apply_filters( 'krste_filter_default_sidebar_id', 'primary-sidebar', 'primary' );
    if ( !is_active_sidebar( $default_sidebar ) ) {
        $classes[] = 'krste-no-sidebar no-sidebar';
    }
    return $classes;
}

add_filter( 'body_class', 'krste_body_classes' );
/**
 * Sets the post excerpt length to n words.
 *
 * function tied to the excerpt_length filter hook.
 *
 * @uses filter excerpt_length
 */
function krste_excerpt_length( $length )
{
    if ( is_admin() || !krste_app()->has( 'store.excerpt_length' ) ) {
        return $length;
    }
    return absint( krste_app()['store.excerpt_length'] );
}

add_filter( 'excerpt_length', 'krste_excerpt_length' );
/**
 * Replaces "[...]" (appended to automatically generated excerpts) with ... and a option from customizer
 *
 * @return string option from customizer prepended with an ellipsis.
 */
function krste_excerpt_more( $link )
{
    if ( is_admin() || !krste_app()->has( 'store.excerpt_more_text' ) ) {
        return $link;
    }
    return krste_app()['store.excerpt_more_text'];
}

add_filter( 'excerpt_more', 'krste_excerpt_more' );
/**
 * Change customizer localize object
 *
 * @param $localize
 *
 * @return mixed
 */
function krste_customizer_localize( $localize )
{
    $localize['customizer']['colorPicker']['swatches'] = [
        'var(--krste-primary-color)',
        'var(--krste-primary-active)',
        'var(--krste-accent-color)',
        'var(--krste-accent-active)',
        'var(--krste-base-300)',
        'var(--krste-base-200)',
        'var(--krste-base-100)',
        'var(--krste-base-50)',
        'var(--krste-base-color)'
    ];
    return $localize;
}

add_filter( 'lotta_filter_customizer_js_localize', 'krste_customizer_localize' );
/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function krste_pingback_header()
{
    if ( is_singular() && pings_open() ) {
        printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
    }
}

add_action( 'wp_head', 'krste_pingback_header' );
function krste_selective_refresh_dynamic_css()
{
    if ( is_customize_preview() ) {
        ?>
        <style id="krste-selective-dynamic-css"></style>
		<?php 
    }
}

add_action( 'wp_footer', 'krste_selective_refresh_dynamic_css' );
/**
 * Add primary sidebar
 *
 * @param $layout
 */
function krste_add_primary_sidebar( $layout )
{
    // Include primary sidebar.
    if ( $layout === 'left-sidebar' || $layout === 'right-sidebar' ) {
        get_sidebar();
    }
}

add_action( 'krste_action_sidebar', 'krste_add_primary_sidebar' );
/**
 * Add mobile modal
 */
function krste_add_mobile_modal()
{
    if ( !CZ::checked( 'krste_header_mobile_modal' ) ) {
        return;
    }
    $attrs = [
        'class' => 'krste-modal krste-mobile-menu-modal',
        'id'    => 'krste-mobile-menu-modal',
    ];
    
    if ( is_customize_preview() ) {
        $attrs['data-shortcut'] = 'border';
        $attrs['data-shortcut-location'] = 'krste_header:krste_header_mobile_menu';
    }
    
    ?>
    <div <?php 
    Utils::print_attribute_string( $attrs );
    ?>>
        <div class="krste-modal-actions">
            <button id="krste-close-mobile-menu-modal-button"
                    class="krste-close-modal"
                    data-toggle-target="#krste-mobile-menu-modal"
                    type="button"
            >
				<?php 
    echo  krste_image( 'times' ) ;
    ?>
            </button>
        </div>
        <div class="krste-modal-content" data-redirect-focus="#krste-close-mobile-menu-modal-button">
			<?php 
    if ( CZ::checked( 'krste_header_mobile_menu' ) ) {
        ( new Krste_Mobile_Menu_Element( 'krste_mobile_menu' ) )->render();
    }
    
    if ( CZ::checked( 'krste_header_mobile_widgets' ) ) {
        ?>
                <div class="krste-mobile-widgets krste-form py-gutter prose prose-krste shrink-0 krste-heading">
					<?php 
        dynamic_sidebar( 'mobile-widgets' );
        ?>
                </div>
				<?php 
    }
    
    ?>
        </div>
    </div>
	<?php 
}

add_action( 'krste_action_before_header', 'krste_add_mobile_modal' );
/**
 * Add search modal
 */
function krste_add_search_modal()
{
    if ( !CZ::checked( 'krste_header_search' ) ) {
        return;
    }
    $attrs = [
        'class' => 'krste-modal krste-search-modal',
        'id'    => 'krste-search-modal',
    ];
    
    if ( is_customize_preview() ) {
        $attrs['data-shortcut'] = 'border';
        $attrs['data-shortcut-location'] = 'krste_header:krste_header_search';
    }
    
    ?>
    <div <?php 
    Utils::print_attribute_string( $attrs );
    ?>>
        <div class="krste-modal-content" data-redirect-focus="#krste-close-search-modal">
            <div class="max-w-screen-md mx-auto mt-60 krste-search-modal-form form-controls form-underline"
                 data-redirect-focus="#krste-close-search-modal-button">
				<?php 
    get_search_form( [
        'placeholder'    => esc_html( CZ::get( 'krste_header_search_placeholder' ) ),
        'disable_submit' => true,
    ] );
    ?>
            </div>
        </div>
        <div class="krste-modal-actions">
            <button id="krste-close-search-modal-button"
                    class="krste-close-modal"
                    data-toggle-target="#krste-search-modal"
                    type="button"
            >
				<?php 
    echo  krste_image( 'times' ) ;
    ?>
            </button>
        </div>
    </div>
	<?php 
}

add_action( 'krste_action_before_header', 'krste_add_search_modal' );
/**
 * Site header open
 */
function krste_add_header_open()
{
    ?>
    <header class="krste-site-header">
	<?php 
}

add_action( 'krste_action_before_header', 'krste_add_header_open' );
/**
 * Add primary navbar
 */
function krste_add_primary_navbar()
{
    get_template_part( 'template-parts/header', 'navbar' );
}

add_action( 'krste_action_header', 'krste_add_primary_navbar' );
/**
 * Site header closed
 */
function krste_add_header_close()
{
    ?>
    </header>
	<?php 
}

add_action( 'krste_action_after_header', 'krste_add_header_close' );
/**
 * Show posts pagination
 */
function krste_show_posts_pagination()
{
    global  $wp_query ;
    $pages = $wp_query->max_num_pages;
    global  $paged ;
    $paged = ( empty($paged) ? 1 : $paged );
    // Don't print empty markup in archives if there's only one page or pagination is disabled.
    if ( !CZ::checked( 'krste_archive_pagination_section' ) || $pages < 2 && (is_home() || is_archive() || is_search()) ) {
        return;
    }
    $type = CZ::get( 'krste_pagination_type' );
    $show_disabled_button = CZ::checked( 'krste_pagination_disabled_button' );
    $css = [ 'krste-pagination' ];
    $pagination_attrs = [
        'class'                     => Utils::clsx( $css ),
        'data-pagination-type'      => $type,
        'data-pagination-max-pages' => $pages,
    ];
    
    if ( is_customize_preview() ) {
        $pagination_attrs['data-shortcut'] = 'border';
        $pagination_attrs['data-shortcut-location'] = 'krste_posts:krste_archive_pagination_section';
    }
    
    $btn_class = 'krste-btn';
    $current_btn_class = $btn_class . ' krste-btn-active';
    $disabled_btn_class = $btn_class . ' krste-btn-disabled';
    $show_previous_button = function ( $disabled = false ) use( $paged, $btn_class, $disabled_btn_class ) {
        $prev_type = CZ::get( 'krste_pagination_prev_next_type' );
        
        if ( $disabled ) {
            echo  '<span class="' . esc_attr( $disabled_btn_class . ' krste-prev-btn krste-prev-btn-' . $prev_type ) . '">' ;
        } else {
            echo  '<a href="' . esc_url( get_pagenum_link( $paged - 1, true ) ) . '" class="' . esc_attr( $btn_class . ' krste-prev-btn krste-prev-btn-' . $prev_type ) . '">' ;
        }
        
        
        if ( $prev_type === 'text' ) {
            echo  '<span>' . esc_html( CZ::get( 'krste_pagination_prev_text' ) ) . '</span>' ;
        } else {
            echo  krste_image( 'prev-arrow' ) ;
        }
        
        echo  ( $disabled ? '</span>' : '</a>' ) ;
    };
    $show_next_button = function ( $disabled = false ) use( $paged, $btn_class, $disabled_btn_class ) {
        $next_type = CZ::get( 'krste_pagination_prev_next_type' );
        
        if ( $disabled ) {
            echo  '<span class="' . esc_attr( $disabled_btn_class . ' krste-next-btn krste-next-btn-' . $next_type ) . '">' ;
        } else {
            echo  '<a href="' . esc_url( get_pagenum_link( $paged + 1, true ) ) . '" class="' . esc_attr( $btn_class . ' krste-next-btn krste-next-btn-' . $next_type ) . '">' ;
        }
        
        echo  '<span>' ;
        
        if ( $next_type === 'text' ) {
            echo  esc_html( (string) CZ::get( 'krste_pagination_next_text' ) ) ;
        } else {
            echo  krste_image( 'next-arrow' ) ;
        }
        
        echo  '</span>' ;
        echo  ( $disabled ? '</span>' : '</a>' ) ;
    };
    echo  '<nav ' . Utils::render_attribute_string( $pagination_attrs ) . '>' ;
    
    if ( 'prev-next' === $type ) {
        // Show previous button
        
        if ( $paged > 1 ) {
            $show_previous_button();
        } elseif ( $show_disabled_button ) {
            $show_previous_button( true );
        }
        
        // Show next button
        
        if ( $paged < $pages ) {
            $show_next_button();
        } elseif ( $show_disabled_button ) {
            $show_next_button( true );
        }
    
    } elseif ( 'numbered' === $type ) {
        $range = 2;
        $showitems = $range * 2 + 1;
        // Show previous button
        if ( CZ::checked( 'krste_pagination_prev_next_button' ) ) {
            
            if ( $paged > 1 ) {
                $show_previous_button();
            } elseif ( $show_disabled_button ) {
                $show_previous_button( true );
            }
        
        }
        // Show numeric buttons
        for ( $i = 1 ;  $i <= $pages ;  $i++ ) {
            if ( 1 !== $pages && (!($i >= $paged + $range + 1 || $i <= $paged - $range - 1) || $pages <= $showitems) ) {
                
                if ( $paged === $i ) {
                    echo  '<span class="' . esc_attr( $current_btn_class ) . '">' . $i . '</span>' ;
                } else {
                    echo  '<a class="' . esc_attr( $btn_class ) . '" href="' . esc_url( get_pagenum_link( $i, true ) ) . '">' . $i . '</a>' ;
                }
            
            }
        }
        // Show next button
        if ( CZ::checked( 'krste_pagination_prev_next_button' ) ) {
            
            if ( $paged < $pages ) {
                $show_next_button();
            } elseif ( $show_disabled_button ) {
                $show_next_button( true );
            }
        
        }
    } else {
    }
    
    echo  '</nav>' ;
}

add_action( 'krste_action_posts_pagination', 'krste_show_posts_pagination' );
/**
 * Show page content
 */
function krste_show_page_content()
{
    $header = !(is_front_page() && !is_home()) || CZ::checked( 'krste_show_frontpage_header' );
    krste_show_article( 'krste_pages', 'page', $header );
}

add_action( 'krste_action_page', 'krste_show_page_content' );
/**
 * Show single post content
 */
function krste_show_single_post_content()
{
    krste_show_article( 'krste_single_post', 'post' );
}

add_action( 'krste_action_single_post', 'krste_show_single_post_content' );
/**
 * Show posts navigation
 */
function krste_add_post_navigation()
{
    if ( !CZ::checked( 'krste_post_navigation' ) ) {
        return;
    }
    
    if ( is_customize_preview() ) {
        $attrs = [
            'data-shortcut'          => 'border',
            'data-shortcut-location' => 'krste_single_post:krste_post_navigation',
        ];
        echo  '<div ' . Utils::render_attribute_string( $attrs ) . '>' ;
    }
    
    echo  '<div class="krste-max-w-content mx-auto">' ;
    the_post_navigation( [
        'prev_text'          => krste_image( 'prev-arrow' ) . '<span class="px-half-gutter">%title</span>',
        'next_text'          => krste_image( 'next-arrow' ) . '<span class="px-half-gutter">%title</span>',
        'screen_reader_text' => '<span class="nav-subtitle screen-reader-text">' . esc_html__( 'Page', 'krste' ) . '</span>',
        'class'              => 'krste-post-navigation',
    ] );
    if ( is_customize_preview() ) {
        echo  '</div>' ;
    }
    echo  '</div>' ;
}

add_action( 'krste_action_after_single_post', 'krste_add_post_navigation' );
function krste_show_post_comments()
{
    // If comments are open, or we have at least one comment, load up the comment template.
    if ( comments_open() || get_comments_number() ) {
        comments_template();
    }
}

add_action( 'krste_action_after_page', 'krste_show_post_comments', 30 );
add_action( 'krste_action_after_single_post', 'krste_show_post_comments', 30 );
/**
 * Footer area start
 */
function krste_footer_start()
{
    $attrs = [
        'class' => 'krste-site-footer',
    ];
    
    if ( is_customize_preview() ) {
        $attrs['data-shortcut'] = 'border';
        $attrs['data-shortcut-location'] = 'krste_footer';
    }
    
    ?>
    <footer <?php 
    Utils::print_attribute_string( $attrs );
    ?>>
    <div class="container mx-auto px-half-gutter flex flex-col">
	<?php 
}

add_action( 'krste_action_before_footer', 'krste_footer_start', 20 );
/**
 * Footer area end
 */
function krste_footer_end()
{
    ?>
    </div>
    </footer>
	<?php 
}

add_action( 'krste_action_after_footer', 'krste_footer_end' );
/**
 * Add to top button
 */
function krste_add_scroll_to_top()
{
    
    if ( CZ::checked( 'krste_scroll_to_top' ) ) {
        $css = [ 'krste-to-top', 'hidden', 'krste-to-top-' . CZ::get( 'krste_to_top_position' ) ];
        $attrs = [
            'href'  => '#',
            'id'    => 'scroll-top',
            'class' => Utils::clsx( $css ),
        ];
        echo  '<a ' . Utils::render_attribute_string( $attrs ) . '>' ;
        
        if ( is_customize_preview() ) {
            echo  '<div data-shortcut="arrow" data-shortcut-location="krste_layout:krste_scroll_to_top">' ;
            echo  '</div>' ;
        }
        
        echo  krste_image( CZ::get( 'krste_to_top_icon' ) ) ;
        echo  '</a>' ;
    }

}

add_action( 'krste_action_after_footer', 'krste_add_scroll_to_top' );
/**
 * Add footer logo
 */
function krste_add_footer_logo()
{
    if ( CZ::checked( 'krste_footer_logo' ) ) {
        ( new Krste_Logo_Element( 'krste_footer_logo' ) )->render( [
            'attrs'    => [
            'class' => 'krste-footer-item',
        ],
            'location' => 'krste_footer:krste_footer_logo',
        ] );
    }
}

add_action( 'krste_action_footer', 'krste_add_footer_logo', 10 );
/**
 * Add footer menu
 */
function krste_add_footer_menu()
{
    
    if ( CZ::checked( 'krste_footer_menu' ) ) {
        $attrs = [
            'class' => 'krste-footer-item',
        ];
        
        if ( is_customize_preview() ) {
            $attrs['data-shortcut'] = 'arrow';
            $attrs['data-shortcut-location'] = 'krste_footer:krste_footer_menu';
        }
        
        ( new Krste_Menu_Element( 'krste_footer_menu' ) )->render( [
            'container_attrs' => $attrs,
        ] );
    }

}

add_action( 'krste_action_footer', 'krste_add_footer_menu', 20 );
/**
 * Add footer copyright
 */
function krste_add_footer_copyright()
{
    $attrs = [
        'class' => 'krste-footer-item',
    ];
    
    if ( is_customize_preview() ) {
        $attrs['data-shortcut'] = 'arrow';
        $attrs['data-shortcut-location'] = 'krste_footer:krste_footer_copyright';
    }
    
    ( new Krste_Copyright_Element( 'krste_footer_copyright' ) )->render( $attrs );
}

add_action( 'krste_action_footer', 'krste_add_footer_copyright', 30 );
function krste_add_admin_menu()
{
    add_theme_page(
        esc_html__( 'Krste Theme', 'krste' ),
        esc_html__( 'Krste Theme', 'krste' ),
        'edit_theme_options',
        'krste',
        function () {
        get_template_part( 'template-parts/admin', 'welcome' );
    }
    );
}

add_action( 'admin_menu', 'krste_add_admin_menu' );