<?php

/**
 * Krste Theme Setup
 *
 * @package Krste
 */
use  LottaFramework\Facades\Css ;
use  LottaFramework\Facades\CZ ;
use  LottaFramework\Typography\Fonts ;
use  LottaFramework\Utils ;
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function krste_setup()
{
    /*
     * Make theme available for translation.
     * Translations can be filed in the /languages/ directory.
     * If you're building a theme based on Krste, use a find and replace
     * to change 'krste' to the name of your theme in all the template files.
     */
    load_theme_textdomain( 'krste', get_template_directory() . '/languages' );
    // Add default posts and comments RSS feed links to head.
    add_theme_support( 'automatic-feed-links' );
    /*
     * Let WordPress manage the document title.
     * By adding theme support, we declare that this theme does not use a
     * hard-coded <title> tag in the document head, and expect WordPress to
     * provide it for us.
     */
    add_theme_support( 'title-tag' );
    /*
     * Enable support for Post Thumbnails on posts and pages.
     *
     * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
     */
    add_theme_support( 'post-thumbnails' );
    // Support align wide
    add_theme_support( 'align-wide' );
    // Gutenberg custom stylesheet
    add_theme_support( 'editor-styles' );
    add_editor_style( 'dist/css/editor-style' . (( defined( 'WP_DEBUG' ) && WP_DEBUG ? '' : '.min' )) . '.css' );
    // This theme uses wp_nav_menu() in multi locations.
    register_nav_menus( array(
        'krste_desktop_menu' => esc_html__( 'Primary Desktop Menu', 'krste' ),
        'krste_mobile_menu'  => esc_html__( 'Primary Mobile Menu', 'krste' ),
        'krste_footer_menu'  => esc_html__( 'Footer Menu', 'krste' ),
    ) );
    /*
     * Switch default core markup for search form, comment form, and comments
     * to output valid HTML5.
     */
    add_theme_support( 'html5', array(
        'search-form',
        'comment-form',
        'comment-list',
        'gallery',
        'caption',
        'style',
        'script'
    ) );
    // Support responsive embeds
    add_theme_support( "responsive-embeds" );
    // Add theme support for selective refresh for widgets.
    add_theme_support( 'customize-selective-refresh-widgets' );
}

add_action( 'after_setup_theme', 'krste_setup' );
/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function krste_widgets_init()
{
    $sidebar_tag = CZ::get( 'krste_sidebar_widget_title_tag' );
    $mobile_widgets_tag = CZ::get( 'krste_mobile_widgets_widget_title_tag' );
    register_sidebar( array(
        'name'          => esc_html__( 'Primary Sidebar', 'krste' ),
        'id'            => 'primary-sidebar',
        'description'   => esc_html__( 'Add widgets here.', 'krste' ),
        'before_widget' => '<section id="%1$s" class="krste-widget clearfix %2$s">',
        'after_widget'  => '</section>',
        'before_title'  => '<' . $sidebar_tag . ' class="widget-title mb-half-gutter heading-content">',
        'after_title'   => '</' . $sidebar_tag . '>',
    ) );
    register_sidebar( array(
        'name'          => esc_html__( 'Mobile Widgets', 'krste' ),
        'id'            => 'mobile-widgets',
        'description'   => esc_html__( 'Add widgets here.', 'krste' ),
        'before_widget' => '<section id="%1$s" class="krste-widget clearfix %2$s">',
        'after_widget'  => '</section>',
        'before_title'  => '<' . $mobile_widgets_tag . ' class="widget-title mb-half-gutter heading-content">',
        'after_title'   => '</' . $mobile_widgets_tag . '>',
    ) );
}

add_action( 'widgets_init', 'krste_widgets_init' );
/**
 * Generate dynamic css for admin
 *
 * @return mixed
 */
function krste_admin_dynamic_css()
{
    $css = [];
    $css['.editor-styles-wrapper'] = array_merge( krste_content_images_css(), Css::background( CZ::get( 'krste_site_background' ) ) );
    $css['.editor-styles-wrapper .wp-block-button'] = krste_content_buttons_css();
    return Css::parse( apply_filters( 'krste_filter_admin_dynamic_css', krste_content_typography_css( '.editor-styles-wrapper', $css ) ) );
}

/**
 * Generate dynamic css
 *
 * @return mixed
 */
function krste_dynamic_css()
{
    $css = [];
    /**
     * Site background
     */
    $css['.krste-body'] = array_merge( Css::background( CZ::get( 'krste_site_background' ) ), [
        '--wp-admin-bar-height' => ( !is_admin_bar_showing() ? [] : [
        'desktop' => '32px',
        'tablet'  => '32px',
        'mobile'  => '46px',
    ] ),
    ] );
    /**
     * Container css
     */
    $post_type = 'archive';
    if ( is_page() ) {
        $post_type = 'pages';
    }
    if ( is_single() ) {
        $post_type = 'single_post';
    }
    if ( is_front_page() && !is_home() ) {
        $post_type = 'homepage';
    }
    $css['.krste-container'] = array_merge( Css::dimensions( CZ::get( "krste_{$post_type}_content_spacing" ), 'margin' ), [
        '--krste-max-w-content' => CZ::get( "krste_{$post_type}_content_width" ),
    ] );
    /**
     * Header
     */
    $css['.krste-site-header'] = array_merge(
        Css::border( CZ::get( 'krste_header_border_top' ), 'border-top' ),
        Css::border( CZ::get( 'krste_header_border_bottom' ), 'border-bottom' ),
        Css::shadow( CZ::get( 'krste_header_shadow' ) ),
        Css::background( CZ::get( 'krste_header_background' ) ),
        [
        'min-height' => CZ::get( 'krste_header_min_height' ),
    ]
    );
    /**
     * Footer
     */
    $css['.krste-site-footer'] = array_merge(
        [
        '--krste-footer-items-spacing' => CZ::get( 'krste_footer_items_spacing' ),
    ],
        Css::border( CZ::get( 'krste_footer_border_top' ), 'border-top' ),
        Css::border( CZ::get( 'krste_footer_border_bottom' ), 'border-bottom' ),
        Css::shadow( CZ::get( 'krste_footer_shadow' ) ),
        Css::background( CZ::get( 'krste_footer_background' ) ),
        Css::dimensions( CZ::get( 'krste_footer_padding' ), 'padding' ),
        Css::dimensions( CZ::get( 'krste_footer_margin' ), 'margin' )
    );
    $css['.krste-site-footer .container'] = [
        'align-items' => CZ::get( 'krste_footer_content_alignment' ),
    ];
    /**
     * Site branding
     */
    if ( CZ::checked( 'krste_header_logo' ) ) {
        $css = ( new Krste_Logo_Element( 'krste_header_logo' ) )->css( $css );
    }
    if ( CZ::checked( 'krste_footer_logo' ) ) {
        $css = ( new Krste_Logo_Element( 'krste_footer_logo' ) )->css( $css );
    }
    /**
     * Desktop primary menu
     */
    $css = ( new Krste_Mobile_Menu_Element( 'krste_mobile_menu' ) )->css( $css );
    /**
     * Mobile menu
     */
    $css = ( new Krste_Menu_Element( 'krste_desktop_menu' ) )->css( $css );
    $css['.krste-mobile-menu-modal'] = array_merge( Css::background( CZ::get( 'krste_mobile_menu_modal_background' ) ), Css::colors( CZ::get( 'krste_mobile_menu_modal_close_color' ), [
        'initial' => '--krste-modal-action-initial',
        'hover'   => '--krste-modal-action-hover',
    ] ) );
    $css['.krste-mobile-menu-modal .krste-modal-content'] = Css::dimensions( CZ::get( 'krste_mobile_menu_modal_padding' ), 'padding' );
    /**
     * Search modal
     */
    $css['.krste-search-modal'] = array_merge(
        Css::background( CZ::get( 'krste_search_modal_background' ) ),
        Css::colors( CZ::get( 'krste_search_modal_close_color' ), [
        'initial' => '--krste-modal-action-initial',
        'hover'   => '--krste-modal-action-hover',
    ] ),
        Css::colors( CZ::get( 'krste_header_search_input_color' ), [
        'initial'     => '--krste-search-input-initial-color',
        'focus'       => '--krste-search-input-focus-color',
        'placeholder' => '--krste-search-input-placeholder-color',
    ] ),
        Css::colors( CZ::get( 'krste_header_search_input_border_color' ), [
        'initial' => '--krste-search-input-border-initial-color',
        'focus'   => '--krste-search-input-border-focus-color',
    ] )
    );
    $css['.krste-search-modal .krste-modal-content'] = Css::dimensions( CZ::get( 'krste_search_modal_padding' ), 'padding' );
    /**
     * Footer menu
     */
    if ( CZ::checked( 'krste_footer_menu' ) ) {
        $css = ( new Krste_Menu_Element( 'krste_footer_menu' ) )->css( $css );
    }
    /**
     * Footer copyright
     */
    $css = ( new Krste_Copyright_Element( 'krste_footer_copyright' ) )->css( $css );
    /**
     * Post card
     */
    
    if ( is_archive() || is_home() || is_search() ) {
        if ( CZ::checked( 'krste_entry_divider_section' ) ) {
            $css['.krste-posts'] = array_merge( Css::border( CZ::get( 'krste_entry_items_divider' ), '--krste-divider' ), [
                '--krste-divider-spacing'   => CZ::get( 'krste_entry_items_divider_spacing' ),
                '--krste-divider-alignment' => CZ::get( 'krste_entry_items_divider_alignment' ),
                '--krste-divider-width'     => CZ::get( 'krste_entry_items_divider_width' ),
            ] );
        }
        $css['.card'] = array_merge(
            Css::background( CZ::get( 'krste_card_background' ) ),
            Css::shadow( CZ::get( 'krste_card_shadow' ) ),
            Css::border( CZ::get( 'krste_card_border' ) ),
            Css::dimensions( CZ::get( 'krste_card_radius' ), 'border-radius' ),
            [
            'text-align'             => CZ::get( 'krste_card_content_alignment' ),
            '--card-content-spacing' => CZ::get( 'krste_card_content_spacing' ),
        ]
        );
        /**
         * Archive title
         */
        $css['.krste-archive-header'] = array_merge( [
            'text-align' => CZ::get( 'krste_archive_header_alignment' ),
        ], Css::dimensions( CZ::get( 'krste_archive_header_padding' ), 'padding' ) );
        $css['.krste-archive-header .archive-title'] = array_merge( Css::typography( CZ::get( 'krste_archive_title_typography' ) ), Css::colors( CZ::get( 'krste_archive_title_color' ), [
            'initial' => 'color',
        ] ) );
        $css['.krste-archive-header .archive-description'] = array_merge( Css::typography( CZ::get( 'krste_archive_description_typography' ) ), Css::colors( CZ::get( 'krste_archive_description_color' ), [
            'initial' => 'color',
        ] ) );
        /**
         * Posts pagination
         */
        
        if ( CZ::checked( 'krste_archive_pagination_section' ) ) {
            $pagination_type = CZ::get( 'krste_pagination_type' );
            $pagination_css = [];
            
            if ( $pagination_type === 'numbered' || $pagination_type === 'prev-next' ) {
                $button_color = CZ::get( 'krste_pagination_button_color' );
                $pagination_css = array_merge( Css::border( CZ::get( 'krste_pagination_button_border' ), '--krste-pagination-button-border' ), [
                    '--krste-pagination-button-radius' => CZ::get( 'krste_pagination_button_radius' ),
                    '--krste-pagination-initial-color' => $button_color['initial'] ?? '',
                    '--krste-pagination-active-color'  => $button_color['active'] ?? '',
                    '--krste-pagination-accent-color'  => $button_color['accent'] ?? '',
                ] );
            }
            
            $css['.krste-pagination'] = array_merge( $pagination_css, [
                'justify-content' => CZ::get( 'krste_pagination_alignment' ),
            ] );
        }
    
    }
    
    /**
     * Post elements
     */
    $post_elements_scope = [
        'entry' => [
        'condition' => is_archive() || is_home() || is_search(),
        'elements'  => [
        'title',
        'metas',
        'categories',
        'tags',
        'excerpt',
        'thumbnail',
        'divider',
        'read-more'
    ],
        'selector'  => '.card',
    ],
        'post'  => [
        'condition' => is_single(),
        'elements'  => [
        'title',
        'metas',
        'categories',
        'tags'
    ],
        'selector'  => '.krste-article-header',
    ],
        'page'  => [
        'condition' => is_page(),
        'elements'  => [
        'title',
        'metas',
        'categories',
        'tags'
    ],
        'selector'  => '.krste-article-header',
    ],
    ];
    foreach ( $post_elements_scope as $id => $scope ) {
        if ( !$scope['condition'] ) {
            continue;
        }
        $scope_selector = $scope['selector'];
        $css = array_merge( $css, krste_post_elements_css( $scope_selector, $id, $scope['elements'] ) );
    }
    /**
     * Widgets
     */
    $sidebars = [
        'sidebar'        => '.krste-sidebar',
        'mobile_widgets' => '.krste-mobile-widgets',
    ];
    foreach ( $sidebars as $id => $selector ) {
        $css[$selector . ' .krste-widget'] = array_merge(
            Css::typography( CZ::get( 'krste_' . $id . '_widget_typography' ) ),
            Css::background( CZ::get( 'krste_' . $id . '_background' ) ),
            Css::border( CZ::get( 'krste_' . $id . '_border' ) ),
            Css::shadow( CZ::get( 'krste_' . $id . '_shadow' ) ),
            Css::dimensions( CZ::get( 'krste_' . $id . '_spacing' ), 'padding' ),
            Css::dimensions( CZ::get( 'krste_' . $id . '_radius' ), 'border-radius' )
        );
        $css[$selector . ' .widget-title'] = array_merge( Css::typography( CZ::get( 'krste_' . $id . '_widget_title_typography' ) ), Css::colors( CZ::get( 'krste_' . $id . '_widget_title_color' ), [
            'initial'   => 'color',
            'indicator' => '--krste-heading-indicator',
        ] ) );
        $css[$selector] = array_merge( Css::colors( CZ::get( 'krste_' . $id . '_widget_color' ), [
            'text'    => '--krste-widgets-text-color',
            'initial' => '--krste-widgets-link-initial',
            'hover'   => '--krste-widgets-link-hover',
        ] ), Css::border( CZ::get( 'krste_' . $id . '_widgets_divider' ), '--krste-widgets-divider' ), [
            '--krste-sidebar-width'   => CZ::get( 'krste_' . $id . '_width' ) ?? '100%',
            '--krste-sidebar-gap'     => CZ::get( 'krste_' . $id . '_gap' ) ?? '24px',
            '--krste-widgets-spacing' => CZ::get( 'krste_' . $id . '_widgets_spacing' ) ?? '24px',
        ] );
    }
    /**
     * Buttons
     */
    $css['.krste-article-content .wp-block-button, .krste-comments-area [type="submit"], .krste-form [type="submit"]'] = krste_content_buttons_css();
    /**
     * Single post & page
     */
    
    if ( is_single() || is_page() ) {
        $article_type = ( is_page() ? 'page' : 'post' );
        $prefix = 'krste_' . $article_type;
        // Article header
        $css['.krste-article-header'] = array_merge( Css::dimensions( CZ::get( "{$prefix}_header_spacing" ), 'padding' ), [
            'text-align' => CZ::get( "{$prefix}_header_alignment" ),
        ] );
        // Article thumbnail
        $css['.article-featured-image'] = Css::dimensions( CZ::get( "{$prefix}_featured_image_spacing" ), 'padding' );
        $css['.article-featured-image img'] = array_merge( [
            'height' => CZ::get( "{$prefix}_featured_image_height" ),
        ], Css::shadow( CZ::get( "{$prefix}_featured_image_shadow" ) ), Css::dimensions( CZ::get( "{$prefix}_featured_image_radius" ), 'border-radius' ) );
        // Article images
        $css['.krste-article-content'] = krste_content_images_css();
        // Article typography
        $css = krste_content_typography_css( '.krste-article-content', $css );
        // Post navigation
        if ( is_single() ) {
            $css['.krste-post-navigation'] = array_merge(
                Css::dimensions( CZ::get( 'krste_post_navigation_padding' ), 'padding' ),
                Css::dimensions( CZ::get( 'krste_post_navigation_margin' ), 'margin' ),
                Css::border( CZ::get( 'krste_post_navigation_border_top' ), 'border-top' ),
                Css::border( CZ::get( 'krste_post_navigation_border_bottom' ), 'border-bottom' ),
                Css::colors( CZ::get( 'krste_post_navigation_text_color' ), [
                'initial' => '--krste-navigation-initial-color',
                'hover'   => '--krste-navigation-hover-color',
            ] )
            );
        }
        // Post comments
        $css['.krste-comments-area'] = array_merge(
            Css::typography( CZ::get( 'krste_content_comments_typography' ) ),
            Css::colors( CZ::get( 'krste_content_comments_text_color' ), [
            'initial' => '--krste-comments-initial-color',
            'hover'   => '--krste-comments-hover-color',
        ] ),
            Css::colors( CZ::get( 'krste_content_comments_form_color' ), [
            'background' => '--krste-form-background-color',
            'border'     => '--krste-form-border-color',
            'active'     => '--krste-form-active-color',
        ] ),
            Css::dimensions( CZ::get( 'krste_content_comments_padding' ), 'padding' ),
            Css::dimensions( CZ::get( 'krste_content_comments_margin' ), 'margin' ),
            Css::border( CZ::get( 'krste_content_comments_border_top' ), 'border-top' ),
            Css::border( CZ::get( 'krste_content_comments_border_bottom' ), 'border-bottom' )
        );
    }
    
    /**
     * To top button
     */
    
    if ( CZ::checked( 'krste_scroll_to_top' ) ) {
        $to_top_css = [
            'box-shadow'                        => '0 10px 20px 0px rgba(44, 62, 80, 0.15)',
            'border-radius'                     => '3px',
            'padding'                           => '16px',
            '--krste-to-top-icon-initial'       => 'var(--krste-base-color)',
            '--krste-to-top-icon-hover'         => 'var(--krste-base-color)',
            '--krste-to-top-background-initial' => 'var(--krste-accent-active)',
            '--krste-to-top-background-hover'   => 'var(--krste-primary-color)',
            '--krste-to-top-icon-size'          => CZ::get( 'krste_to_top_icon_size' ),
            '--krste-to-top-bottom-offset'      => CZ::get( 'krste_to_top_bottom_offset' ),
            '--krste-to-top-side-offset'        => CZ::get( 'krste_to_top_side_offset' ),
        ];
        $css['.krste-to-top'] = $to_top_css;
    }
    
    return Css::parse( $css );
}

/**
 * Generate global css vars
 *
 * @return mixed
 */
function krste_global_css_vars()
{
    $vars = [
        '--krste-transparent' => 'rgba(0, 0, 0, 0)',
    ];
    /**
     * Palette
     */
    $colors = [
        'krste_primary_color'          => [
        'default' => 'krste-primary-color',
        'active'  => 'krste-primary-active',
    ],
        'krste_accent_color'           => [
        'default' => 'krste-accent-color',
        'active'  => 'krste-accent-active',
    ],
        'krste_base_color'             => [
        'default' => 'krste-base-color',
        '50'      => 'krste-base-50',
        '100'     => 'krste-base-100',
        '200'     => 'krste-base-200',
        '300'     => 'krste-base-300',
    ],
        'krste_content_base_color'     => [
        'initial' => 'krste-content-base-color',
    ],
        'krste_content_drop_cap_color' => [
        'initial' => 'krste-content-drop-cap-color',
    ],
        'krste_content_link_color'     => [
        'initial' => 'krste-link-initial-color',
        'hover'   => 'krste-link-hover-color',
    ],
        'krste_content_headings_color' => [
        'initial' => 'krste-headings-color',
    ],
        'krste_content_h1_color'       => [
        'initial' => 'krste-headings-h1-color',
    ],
        'krste_content_h2_color'       => [
        'initial' => 'krste-headings-h2-color',
    ],
        'krste_content_h3_color'       => [
        'initial' => 'krste-headings-h3-color',
    ],
        'krste_content_h4_color'       => [
        'initial' => 'krste-headings-h4-color',
    ],
        'krste_content_h5_color'       => [
        'initial' => 'krste-headings-h5-color',
    ],
        'krste_content_h6_color'       => [
        'initial' => 'krste-headings-h6-color',
    ],
    ];
    $palettes = Utils::array_path( CZ::getSettingArgs( 'krste_color_palettes' ), 'options.palettes' );
    $palette = $palettes[CZ::get( 'krste_color_palettes' )] ?? [];
    foreach ( $colors as $setting => $args ) {
        $color = CZ::get( $setting );
        foreach ( $args as $key => $var ) {
            
            if ( Utils::str_starts_with( $color[$key], 'var' ) && isset( $palette[$var] ) ) {
                $vars['--' . $var] = $palette[$var];
                continue;
            }
            
            $vars['--' . $var] = $color[$key];
        }
    }
    return Css::parse( [
        ':root' => $vars,
    ] );
}

/**
 * @param $scope
 * @param array $css
 *
 * @return array|mixed
 */
function krste_content_typography_css( $scope, $css = array() )
{
    $css[$scope] = array_merge( Css::typography( CZ::get( 'krste_content_base_typography' ) ), $css[$scope] ?? [] );
    $css[$scope . ' .has-drop-cap::first-letter'] = array_merge( Css::typography( CZ::get( 'krste_content_drop_cap_typography' ) ), $css[$scope . ' .has-drop-cap::first-letter'] ?? [] );
    $css[$scope . ' h1'] = array_merge( Css::typography( CZ::get( 'krste_content_h1_typography' ) ), $css[$scope . ' h1'] ?? [] );
    $css[$scope . ' h2'] = array_merge( Css::typography( CZ::get( 'krste_content_h2_typography' ) ), $css[$scope . ' h2'] ?? [] );
    $css[$scope . ' h3'] = array_merge( Css::typography( CZ::get( 'krste_content_h3_typography' ) ), $css[$scope . ' h3'] ?? [] );
    $css[$scope . ' h4'] = array_merge( Css::typography( CZ::get( 'krste_content_h4_typography' ) ), $css[$scope . ' h4'] ?? [] );
    $css[$scope . ' h5'] = array_merge( Css::typography( CZ::get( 'krste_content_h5_typography' ) ), $css[$scope . ' h5'] ?? [] );
    $css[$scope . ' h6'] = array_merge( Css::typography( CZ::get( 'krste_content_h6_typography' ) ), $css[$scope . ' h6'] ?? [] );
    return $css;
}

/**
 * Button css
 *
 * @return array
 */
function krste_content_buttons_css()
{
    return array_merge(
        [
        '--krste-button-height' => CZ::get( 'krste_content_buttons_min_height' ),
    ],
        Css::typography( CZ::get( 'krste_content_buttons_typography' ) ),
        Css::border( CZ::get( 'krste_content_buttons_border' ), '--krste-button-border' ),
        Css::dimensions( CZ::get( 'krste_content_buttons_padding' ), '--krste-button-padding' ),
        Css::dimensions( CZ::get( 'krste_content_buttons_radius' ), '--krste-button-radius' ),
        Css::colors( CZ::get( 'krste_content_buttons_text_color' ), [
        'initial' => '--krste-button-text-initial-color',
        'hover'   => '--krste-button-text-hover-color',
    ] ),
        Css::colors( CZ::get( 'krste_content_buttons_button_color' ), [
        'initial' => '--krste-button-initial-color',
        'hover'   => '--krste-button-hover-color',
    ] )
    );
}

/**
 * @return array
 */
function krste_content_images_css()
{
    return array_merge( Css::dimensions( CZ::get( 'krste_content_images_radius' ), '--krste-content-images-radius' ), Css::border( CZ::get( 'krste_content_images_border' ), '--krste-content-images-border' ), Css::shadow( CZ::get( 'krste_content_images_shadow' ), '--krste-content-images-shadow' ) );
}

/**
 * Enqueue dynamic css for our theme
 */
function krste_enqueue_dynamic_css()
{
    wp_register_style( 'krste-dynamic', false );
    wp_enqueue_style( 'krste-dynamic' );
    wp_add_inline_style( 'krste-dynamic', krste_dynamic_css() );
}

/**
 * Enqueue dynamic css for our theme
 */
function krste_enqueue_admin_dynamic_css()
{
    wp_register_style( 'krste-admin-dynamic', false );
    wp_enqueue_style( 'krste-admin-dynamic' );
    wp_add_inline_style( 'krste-admin-dynamic', krste_admin_dynamic_css() );
}

/**
 * Enqueue global css variables
 */
function krste_enqueue_global_vars()
{
    wp_register_style( 'krste-dynamic-vars', false );
    wp_enqueue_style( 'krste-dynamic-vars' );
    wp_add_inline_style( 'krste-dynamic-vars', krste_global_css_vars() );
}

/**
 * Regenerate dynamic css for selective refresh
 *
 * @return array
 */
function krste_refresh_dynamic_css()
{
    return [ '#krste-selective-dynamic-css', function () {
        echo  krste_dynamic_css() ;
    } ];
}

/**
 * Enqueue scripts and styles.
 */
function krste_enqueue_scripts()
{
    $suffix = ( defined( 'WP_DEBUG' ) && WP_DEBUG ? '' : '.min' );
    // Vendors
    wp_enqueue_script(
        'superfish',
        get_template_directory_uri() . '/dist/vendor/superfish/superfish.min.js',
        [ 'jquery' ],
        KRSTE_VERSION
    );
    wp_enqueue_style(
        'krste-style',
        get_template_directory_uri() . '/dist/css/style' . $suffix . '.css',
        array(),
        KRSTE_VERSION
    );
    wp_enqueue_script(
        'krste-script',
        get_template_directory_uri() . '/dist/js/app' . $suffix . '.js',
        array( 'jquery' ),
        KRSTE_VERSION,
        true
    );
    krste_enqueue_global_vars();
    krste_enqueue_dynamic_css();
    Fonts::enqueue_scripts( 'krste_fonts', KRSTE_VERSION );
    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }
}

add_action( 'wp_enqueue_scripts', 'krste_enqueue_scripts' );
function krste_enqueue_admin_scripts()
{
    $suffix = ( defined( 'WP_DEBUG' ) && WP_DEBUG ? '' : '.min' );
    krste_enqueue_global_vars();
    krste_enqueue_admin_dynamic_css();
    Fonts::enqueue_scripts( 'krste_fonts', KRSTE_VERSION );
    // Theme admin scripts
    wp_register_style(
        'krste-admin-style',
        get_template_directory_uri() . '/dist/css/admin' . $suffix . '.css',
        [],
        KRSTE_VERSION
    );
    wp_enqueue_style( 'krste-admin-style' );
}

add_action( 'admin_enqueue_scripts', 'krste_enqueue_admin_scripts' );
/**
 * Enqueue scripts and styles for customizer.
 */
function krste_enqueue_customizer_scripts()
{
    $suffix = ( defined( 'WP_DEBUG' ) && WP_DEBUG ? '' : '.min' );
    wp_enqueue_style(
        'krste-customizer-style',
        get_template_directory_uri() . '/dist/css/customizer' . $suffix . '.css',
        array(),
        KRSTE_VERSION
    );
}

add_action( 'customize_controls_enqueue_scripts', 'krste_enqueue_customizer_scripts' );