<?php

/**
 * Article trait
 *
 * @package Krste
 */
use  LottaFramework\Customizer\Controls\Border ;
use  LottaFramework\Customizer\Controls\BoxShadow ;
use  LottaFramework\Customizer\Controls\ColorPicker ;
use  LottaFramework\Customizer\Controls\ImageRadio ;
use  LottaFramework\Customizer\Controls\Layers ;
use  LottaFramework\Customizer\Controls\Placeholder ;
use  LottaFramework\Customizer\Controls\Radio ;
use  LottaFramework\Customizer\Controls\Select ;
use  LottaFramework\Customizer\Controls\Separator ;
use  LottaFramework\Customizer\Controls\Slider ;
use  LottaFramework\Customizer\Controls\Spacing ;

if ( !defined( 'ABSPATH' ) ) {
    exit;
    // Exit if accessed directly.
}

if ( !trait_exists( 'Krste_Article_Controls' ) ) {
    /**
     * Article controls
     */
    trait Krste_Article_Controls
    {
        use  Krste_Post_Structure ;
        /**
         * @param $type
         *
         * @return array
         */
        protected function getArticleStructureControls( $type )
        {
            return [ ( new Slider( 'krste_' . $type . '_content_spacing' ) )->setLabel( __( 'Content Area Spacing', 'krste' ) )->enableResponsive()->setDefaultUnit( 'px' )->setDefaultValue( '24px' ) ];
        }
        
        /**
         * @return array
         */
        protected function getHeaderControls( $type, $defaults = array() )
        {
            $defaults = wp_parse_args( $defaults, [
                'elements' => [
                [
                'id'      => 'title',
                'visible' => true,
            ],
                [
                'id'      => 'metas',
                'visible' => true,
            ],
                [
                'id'      => 'categories',
                'visible' => false,
            ],
                [
                'id'      => 'tags',
                'visible' => false,
            ]
            ],
                'metas'    => [],
            ] );
            return [
                ( new Layers( 'krste_' . $type . '_header_elements' ) )->setLabel( __( 'Header Elements', 'krste' ) )->setDefaultValue( $defaults['elements'] )->addLayer( 'title', __( 'Title', 'krste' ), $this->getTitleLayerControls( $type, false, [
                'tag'        => 'h1',
                'typography' => [
                'family'     => 'inherit',
                'fontSize'   => [
                'desktop' => '3rem',
                'tablet'  => '2rem',
                'mobile'  => '1.875em',
            ],
                'variant'    => '700',
                'lineHeight' => '1.25',
            ],
            ] ) )->addLayer( 'metas', __( 'Metas', 'krste' ), $this->getMetasControls( $type, $defaults['metas'] ) )->addLayer( 'categories', __( 'Categories', 'krste' ), $this->getTaxonomyControls( $type, '_cats', [
                'text-initial' => 'var(--krste-accent-active)',
                'text-hover'   => 'var(--krste-primary-active)',
                'typography'   => [
                'family'        => 'inherit',
                'fontSize'      => '0.75rem',
                'variant'       => '400',
                'lineHeight'    => '1.5',
                'textTransform' => 'uppercase',
            ],
            ] ) )->addLayer( 'tags', __( 'Tags', 'krste' ), $this->getTaxonomyControls( $type, '_tags' ) ),
                ( new ImageRadio( 'krste_' . $type . '_header_alignment' ) )->setLabel( __( 'Content Alignment', 'krste' ) )->setDefaultValue( 'center' )->inlineChoices()->setChoices( [
                'left'   => [
                'src'   => krste_image( 'text-left' ),
                'title' => __( 'Left', 'krste' ),
            ],
                'center' => [
                'src'   => krste_image( 'text-center' ),
                'title' => __( 'Center', 'krste' ),
            ],
                'right'  => [
                'src'   => krste_image( 'text-right' ),
                'title' => __( 'Right', 'krste' ),
            ],
            ] ),
                new Separator(),
                ( new Spacing( 'krste_' . $type . '_header_spacing' ) )->setLabel( __( 'Spacing', 'krste' ) )->setDisabled( [ 'left', 'right' ] )->setDefaultValue( [
                'top'    => '64px',
                'right'  => '0px',
                'bottom' => '24px',
                'left'   => '0px',
                'linked' => true,
            ] )
            ];
        }
        
        /**
         * @return array
         */
        protected function getFeaturedImageControls( $type )
        {
            $controls = [
                ( new Select( 'krste_' . $type . '_featured_image_size' ) )->setLabel( __( 'Image Size', 'krste' ) )->setDefaultValue( 'full' )->setChoices( krste_image_size_options( false ) ),
                new Separator(),
                ( new Radio( 'krste_' . $type . '_featured_image_width' ) )->setLabel( __( 'Image Width', 'krste' ) )->buttonsGroupView()->setDefaultValue( 'wide' )->setChoices( [
                'default' => __( 'Default', 'krste' ),
                'wide'    => __( 'Wide', 'krste' ),
                'full'    => __( 'Full', 'krste' ),
            ] ),
                ( new Slider( 'krste_' . $type . '_featured_image_height' ) )->setLabel( __( 'Image Height', 'krste' ) )->setUnits( [ [
                'unit' => 'px',
                'min'  => 100,
                'max'  => 1000,
            ], [
                'unit' => '%',
                'min'  => 10,
                'max'  => 10,
            ] ] )->setDefaultValue( '420px' ),
                new Separator()
            ];
            $controls = array_merge( $controls, [
                krste_upsell_info_control( __( 'More options in %1$sPro Version%2$s', 'krste' ) ),
                ( new Placeholder( 'krste_' . $type . '_featured_image_position' ) )->setDefaultValue( 'below' ),
                ( new Placeholder( 'krste_' . $type . '_featured_image_shadow' ) )->setDefaultShadow(
                'rgba(54,63,70,0.35)',
                '0px',
                '18px',
                '18px',
                '-15px',
                true
            ),
                ( new Placeholder( 'krste_' . $type . '_featured_image_radius' ) )->setDefaultValue( [
                'top'    => '2px',
                'right'  => '2px',
                'bottom' => '2px',
                'left'   => '2px',
                'linked' => true,
            ] ),
                ( new Placeholder( 'krste_' . $type . '_featured_image_spacing' ) )->setDefaultValue( [
                'top'    => '0px',
                'right'  => '0px',
                'bottom' => '0px',
                'left'   => '0px',
            ] )
            ] );
            return $controls;
        }
        
        /**
         * @return array
         */
        protected function getNavigationControls( $type )
        {
            return [
                ( new ColorPicker( 'krste_' . $type . '_navigation_text_color' ) )->setLabel( __( 'Text Color', 'krste' ) )->addColor( 'initial', __( 'Initial', 'krste' ), 'var(--krste-accent-color)' )->addColor( 'hover', __( 'Hover', 'krste' ), 'var(--krste-primary-color)' ),
                ( new Border( 'krste_' . $type . '_navigation_border_top' ) )->setLabel( __( 'Border Top', 'krste' ) )->setDefaultBorder( 2, 'dashed', 'var(--krste-base-200)' ),
                ( new Border( 'krste_' . $type . '_navigation_border_bottom' ) )->setLabel( __( 'Border Bottom', 'krste' ) )->setDefaultBorder( 2, 'dashed', 'var(--krste-base-200)' ),
                new Separator(),
                ( new Spacing( 'krste_' . $type . '_navigation_padding' ) )->setLabel( __( 'Padding', 'krste' ) )->setDisabled( [ 'left', 'right' ] )->setSpacing( [
                'top'    => '24px',
                'bottom' => '24px',
                'linked' => true,
            ] ),
                ( new Spacing( 'krste_' . $type . '_navigation_margin' ) )->setLabel( __( 'Padding', 'krste' ) )->setDisabled( [ 'left', 'right' ] )->setSpacing( [
                'top'    => '24px',
                'bottom' => '24px',
                'linked' => true,
            ] )
            ];
        }
    
    }
}