<?php

/**
 * Button trait
 *
 * @package Krste
 */
use  LottaFramework\Customizer\Controls\Border ;
use  LottaFramework\Customizer\Controls\ColorPicker ;
use  LottaFramework\Customizer\Controls\Placeholder ;
use  LottaFramework\Customizer\Controls\Separator ;
use  LottaFramework\Customizer\Controls\Slider ;
use  LottaFramework\Customizer\Controls\Spacing ;
use  LottaFramework\Customizer\Controls\Typography ;

if ( !defined( 'ABSPATH' ) ) {
    exit;
    // Exit if accessed directly.
}

if ( !trait_exists( 'Krste_Button_Controls' ) ) {
    /**
     * Button controls
     */
    trait Krste_Button_Controls
    {
        /**
         * @param string $id
         * @param array $defaults
         *
         * @return array
         */
        protected function getButtonStyleControls( $id = '', $defaults = array() )
        {
            $defaults = wp_parse_args( $defaults, [
                'text-initial'   => 'var(--krste-base-color)',
                'text-hover'     => 'var(--krste-base-color)',
                'button-initial' => 'var(--krste-accent-active)',
                'button-hover'   => 'var(--krste-primary-color)',
                'border-initial' => 'var(--krste-accent-active)',
                'border-hover'   => 'var(--krste-primary-color)',
                'min-height'     => '36px',
                'border'         => [ 1, 'solid' ],
                'typography'     => [
                'family'        => 'inherit',
                'fontSize'      => '0.75rem',
                'variant'       => '500',
                'lineHeight'    => '1',
                'textTransform' => 'uppercase',
            ],
                'border-radius'  => [
                'linked' => true,
                'left'   => '2px',
                'right'  => '2px',
                'top'    => '2px',
                'bottom' => '2px',
            ],
                'padding'        => [
                'top'    => '1em',
                'right'  => '2.5em',
                'bottom' => '1em',
                'left'   => '2.5em',
            ],
            ] );
            $controls = [
                ( new Slider( $id . 'min_height' ) )->setLabel( __( 'Mini Height', 'krste' ) )->enableResponsive()->setMin( 30 )->setMax( 100 )->setDefaultUnit( 'px' )->setDefaultValue( $defaults['min-height'] ),
                ( new Separator() )->setStyle( 'dashed' ),
                ( new ColorPicker( $id . 'text_color' ) )->setLabel( __( 'Text Color', 'krste' ) )->enableAlpha()->addColor( 'initial', __( 'Initial', 'krste' ), $defaults['text-initial'] )->addColor( 'hover', __( 'Hover', 'krste' ), $defaults['text-hover'] ),
                ( new ColorPicker( $id . 'button_color' ) )->setLabel( __( 'Button Color', 'krste' ) )->enableAlpha()->addColor( 'initial', __( 'Initial', 'krste' ), $defaults['button-initial'] )->addColor( 'hover', __( 'Hover', 'krste' ), $defaults['button-hover'] ),
                ( new Separator() )->setStyle( 'dashed' ),
                ( new Border( $id . 'border' ) )->setLabel( __( 'Border', 'krste' ) )->enableHoverColor()->setDefaultBorder( ...array_merge( $defaults['border'], [ $defaults['border-initial'], $defaults['border-hover'] ] ) ),
                new Separator()
            ];
            $controls = array_merge( $controls, [
                ( new Placeholder( $id . 'typography' ) )->setDefaultValue( $defaults['typography'] ),
                ( new Placeholder( $id . 'radius' ) )->setDefaultValue( $defaults['border-radius'] ),
                ( new Placeholder( $id . 'padding' ) )->setDefaultValue( $defaults['padding'] ),
                krste_upsell_info_control( __( 'More button options in %1$sPro Version%2$s', 'krste' ) )->hideBackground()
            ] );
            return $controls;
        }
    
    }
}