<?php

/**
 * Post card trait
 *
 * @package Krste
 */
use  LottaFramework\Customizer\Controls\Background ;
use  LottaFramework\Customizer\Controls\Border ;
use  LottaFramework\Customizer\Controls\BoxShadow ;
use  LottaFramework\Customizer\Controls\ImageRadio ;
use  LottaFramework\Customizer\Controls\Placeholder ;
use  LottaFramework\Customizer\Controls\Separator ;
use  LottaFramework\Customizer\Controls\Slider ;
use  LottaFramework\Customizer\Controls\Spacing ;

if ( !defined( 'ABSPATH' ) ) {
    exit;
    // Exit if accessed directly.
}

if ( !trait_exists( 'Krste_Post_Card' ) ) {
    /**
     * Post card functions
     */
    trait Krste_Post_Card
    {
        /**
         * @param string $prefix
         * @param array $defaults
         *
         * @return array
         */
        protected function getCardContentControls( $prefix = '', $defaults = array() )
        {
            $defaults = wp_parse_args( $defaults, [
                'spacing'      => '24px',
                'text'         => 'center',
                'vertical'     => 'center',
                'thumb-motion' => 'yes',
            ] );
            return [ ( new Slider( $prefix . 'card_content_spacing' ) )->setLabel( __( 'Content Spacing', 'krste' ) )->enableResponsive()->setDefaultUnit( 'px' )->setDefaultValue( $defaults['spacing'] ), new Separator(), ( new ImageRadio( $prefix . 'card_content_alignment' ) )->setLabel( __( 'Content Alignment', 'krste' ) )->enableResponsive()->inlineChoices()->setDefaultValue( $defaults['text'] )->setChoices( [
                'left'   => [
                'src'   => krste_image( 'text-left' ),
                'title' => __( 'Left', 'krste' ),
            ],
                'center' => [
                'src'   => krste_image( 'text-center' ),
                'title' => __( 'Center', 'krste' ),
            ],
                'right'  => [
                'src'   => krste_image( 'text-right' ),
                'title' => __( 'Right', 'krste' ),
            ],
            ] ) ];
        }
        
        /**
         * @return array
         */
        protected function getCardStyleControls( $prefix = '', $defaults = array() )
        {
            $defaults = wp_parse_args( $defaults, [
                'exclude'       => [],
                'background'    => [
                'type'  => 'color',
                'color' => 'var(--krste-transparent)',
            ],
                'border'        => [ 1, 'none', 'var(--krste-base-200)' ],
                'shadow'        => [
                'rgba(44, 62, 80, 0.45)',
                '0px',
                '15px',
                '18px',
                '-15px'
            ],
                'shadow-enable' => false,
                'radius'        => [
                'top'    => '4px',
                'bottom' => '4px',
                'left'   => '4px',
                'right'  => '4px',
                'linked' => true,
            ],
            ] );
            $exclude = $defaults['exclude'];
            $controls = [];
            if ( !in_array( 'background', $exclude ) ) {
                $controls[] = ( new Background( $prefix . 'card_background' ) )->setLabel( __( 'Card Background', 'krste' ) )->enableResponsive()->setDefaultValue( $defaults['background'] );
            }
            if ( !in_array( 'border', $exclude ) ) {
                $controls[] = ( new Placeholder( $prefix . 'card_border' ) )->setDefaultBorder( ...$defaults['border'] );
            }
            if ( !in_array( 'shadow', $exclude ) ) {
                $controls[] = ( new Placeholder( $prefix . 'card_shadow' ) )->setDefaultShadow( ...array_merge( $defaults['shadow'], [ $defaults['shadow-enable'] ] ) );
            }
            if ( !in_array( 'radius', $exclude ) ) {
                $controls[] = ( new Placeholder( $prefix . 'card_radius' ) )->setDefaultValue( $defaults['radius'] );
            }
            $controls[] = new Separator();
            $controls[] = krste_upsell_info_control( __( 'More card options in %1$sPro Version%2$s', 'krste' ) )->hideBackground();
            return $controls;
        }
    
    }
}