<?php

/**
 * Widgets trait
 *
 * @package Krste
 */
use  LottaFramework\Customizer\Controls\Background ;
use  LottaFramework\Customizer\Controls\Border ;
use  LottaFramework\Customizer\Controls\BoxShadow ;
use  LottaFramework\Customizer\Controls\ColorPicker ;
use  LottaFramework\Customizer\Controls\Placeholder ;
use  LottaFramework\Customizer\Controls\Select ;
use  LottaFramework\Customizer\Controls\Separator ;
use  LottaFramework\Customizer\Controls\Slider ;
use  LottaFramework\Customizer\Controls\Spacing ;
use  LottaFramework\Customizer\Controls\Typography ;

if ( !defined( 'ABSPATH' ) ) {
    exit;
    // Exit if accessed directly.
}

if ( !trait_exists( 'Krste_Widgets_Controls' ) ) {
    trait Krste_Widgets_Controls
    {
        /**
         * @return array
         */
        protected function getSidebarGeneralControls( $id = 'sidebar', $defaults = array() )
        {
            $defaults = wp_parse_args( $defaults, [
                'exclude' => [],
            ] );
            $controls = [];
            
            if ( !in_array( 'title-tag', $defaults['exclude'] ) ) {
                $controls[] = ( new Select( 'krste_' . $id . '_widget_title_tag' ) )->setLabel( __( 'Widget Title Tag', 'krste' ) )->setDefaultValue( 'h2' )->setChoices( [
                    'h1'   => 'H1',
                    'h2'   => 'H2',
                    'h3'   => 'H3',
                    'h4'   => 'H4',
                    'h5'   => 'H5',
                    'h6'   => 'H6',
                    'span' => 'Span',
                ] );
                $controls[] = new Separator();
            }
            
            
            if ( !in_array( 'width', $defaults['exclude'] ) ) {
                $controls[] = ( new Slider( 'krste_' . $id . '_width' ) )->setLabel( __( 'Sidebar Width', 'krste' ) )->setMin( 10 )->setMax( 70 )->setDefaultValue( '27%' )->setDefaultUnit( '%' );
                $controls[] = new Separator();
            }
            
            
            if ( !in_array( 'widgets-spacing', $defaults['exclude'] ) ) {
                $controls[] = ( new Slider( 'krste_' . $id . '_widgets_spacing' ) )->setLabel( __( 'Widgets Spacing', 'krste' ) )->enableResponsive()->setMin( 0 )->setMax( 100 )->setDefaultValue( '24px' )->setDefaultUnit( 'px' );
                $controls[] = new Separator();
            }
            
            if ( !in_array( 'widgets-divider', $defaults['exclude'] ) ) {
                $controls[] = ( new Border( 'krste_' . $id . '_widgets_divider' ) )->setLabel( __( 'Widgets Divider', 'krste' ) )->setDefaultBorder( 1, 'dashed', 'var(--krste-base-300)' );
            }
            return $controls;
        }
        
        /**
         * @return array
         */
        protected function getSidebarStyleControls( $id = 'sidebar' )
        {
            $controls = [
                ( new Typography( 'krste_' . $id . '_widget_title_typography' ) )->setLabel( __( 'Widgets Title Typography', 'krste' ) )->setDefaultValue( [
                'family'     => 'inherit',
                'fontSize'   => '1.25rem',
                'variant'    => '700',
                'lineHeight' => '1.25em',
            ] ),
                ( new ColorPicker( 'krste_' . $id . '_widget_title_color' ) )->setLabel( __( 'Widgets Title Color', 'krste' ) )->addColor( 'initial', __( 'Initial', 'krste' ), 'var(--krste-accent-active)' )->addColor( 'indicator', __( 'Indicator', 'krste' ), 'var(--krste-primary-color)' ),
                new Separator(),
                ( new Typography( 'krste_' . $id . '_widget_typography' ) )->setLabel( __( 'Widgets Typography', 'krste' ) )->setDefaultValue( [
                'family'     => 'inherit',
                'fontSize'   => '0.875rem',
                'variant'    => '400',
                'lineHeight' => '1.75em',
            ] ),
                ( new ColorPicker( 'krste_' . $id . '_widget_color' ) )->setLabel( __( 'Widgets Color', 'krste' ) )->addColor( 'text', __( 'Text Initial', 'krste' ), 'var(--krste-accent-color)' )->addColor( 'initial', __( 'Link Initial', 'krste' ), 'var(--krste-accent-color)' )->addColor( 'hover', __( 'Link Hover', 'krste' ), 'var(--krste-primary-active)' )
            ];
            $controls = array_merge( $controls, [
                ( new Placeholder( 'krste_' . $id . '_background' ) )->setDefaultValue( [
                'type'  => 'color',
                'color' => 'var(--krste-transparent)',
            ] ),
                ( new Placeholder( 'krste_' . $id . '_border' ) )->setDefaultBorder( 1, 'none', 'var(--krste-base-200)' ),
                ( new Placeholder( 'krste_' . $id . '_shadow' ) )->setDefaultShadow(
                'rgba(44, 62, 80, 0.15)',
                '0px',
                '15px',
                '18px',
                '-15px',
                false
            ),
                ( new Placeholder( 'krste_' . $id . '_spacing' ) )->setDefaultValue( [
                'top'    => '12px',
                'right'  => '12px',
                'bottom' => '12px',
                'left'   => '12px',
                'linked' => true,
            ] ),
                ( new Placeholder( 'krste_' . $id . '_radius' ) )->setDefaultValue( [
                'top'    => '2px',
                'bottom' => '2px',
                'left'   => '2px',
                'right'  => '2px',
                'linked' => true,
            ] )
            ] );
            if ( krs_fs()->is_not_paying() ) {
                $controls[] = krste_upsell_info_control( __( 'Fully customize your sidebar in our %1$sPro Version%2$s', 'krste' ) );
            }
            return $controls;
        }
    
    }
}